# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

"""
FILE: set_sip_trunks_sample.py
DESCRIPTION:
    This sample shows the usage of SIP routing client for replacing the collection of
    currently configured SIP trunks with new values.

USAGE:
    python set_sip_trunks_sample.py
        Set the environment variables with your own values before running the sample:
    1) COMMUNICATION_SAMPLES_CONNECTION_STRING - the connection string in your ACS account
    2) COMMUNICATION_SAMPLES_TRUNK_FQDN - FQDN of SipTrunk object to be set
    3) COMMUNICATION_SAMPLES_SIGNALING_PORT - SIP signaling port of SipTrunk object to be set
"""

import os
from azure.communication.phonenumbers.siprouting import SipRoutingClient, SipTrunk

connection_string = os.environ["COMMUNICATION_SAMPLES_CONNECTION_STRING"]
client = SipRoutingClient.from_connection_string(connection_string)
fqdn = os.environ["COMMUNICATION_SAMPLES_TRUNK_FQDN"]
signaling_port = os.environ["COMMUNICATION_SAMPLES_SIGNALING_PORT"]
TRUNKS = [SipTrunk(fqdn=fqdn, sip_signaling_port=signaling_port)]


def set_sip_trunks_sample():
    client.set_trunks(TRUNKS)


if __name__ == "__main__":
    set_sip_trunks_sample()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.datamigration.aio import DataMigrationManagementClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer
from devtools_testutils.aio import recorded_by_proxy_async

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestDataMigrationManagementDatabaseMigrationsSqlDbOperationsAsync(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(DataMigrationManagementClient, is_async=True)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_database_migrations_sql_db_get(self, resource_group):
        response = await self.client.database_migrations_sql_db.get(
            resource_group_name=resource_group.name,
            sql_db_instance_name="str",
            target_db_name="str",
            api_version="2025-06-30",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_database_migrations_sql_db_begin_create_or_update(self, resource_group):
        response = await (
            await self.client.database_migrations_sql_db.begin_create_or_update(
                resource_group_name=resource_group.name,
                sql_db_instance_name="str",
                target_db_name="str",
                parameters={
                    "id": "str",
                    "name": "str",
                    "properties": {
                        "kind": "SqlDb",
                        "endedOn": "2020-02-20 00:00:00",
                        "migrationFailureError": {"code": "str", "message": "str"},
                        "migrationOperationId": "str",
                        "migrationService": "str",
                        "migrationStatus": "str",
                        "migrationStatusDetails": {
                            "listOfCopyProgressDetails": [
                                {
                                    "copyDuration": 0,
                                    "copyStart": "2020-02-20 00:00:00",
                                    "copyThroughput": 0.0,
                                    "dataRead": 0,
                                    "dataWritten": 0,
                                    "parallelCopyType": "str",
                                    "rowsCopied": 0,
                                    "rowsRead": 0,
                                    "status": "str",
                                    "tableName": "str",
                                    "usedParallelCopies": 0,
                                }
                            ],
                            "migrationState": "str",
                            "sqlDataCopyErrors": ["str"],
                        },
                        "offlineConfiguration": {"offline": bool},
                        "provisioningError": "str",
                        "provisioningState": "str",
                        "scope": "str",
                        "sourceDatabaseName": "str",
                        "sourceServerName": "str",
                        "sourceSqlConnection": {
                            "authentication": "str",
                            "dataSource": "str",
                            "encryptConnection": bool,
                            "password": "str",
                            "trustServerCertificate": bool,
                            "userName": "str",
                        },
                        "startedOn": "2020-02-20 00:00:00",
                        "tableList": ["str"],
                        "targetDatabaseCollation": "str",
                        "targetSqlConnection": {
                            "authentication": "str",
                            "dataSource": "str",
                            "encryptConnection": bool,
                            "password": "str",
                            "trustServerCertificate": bool,
                            "userName": "str",
                        },
                    },
                    "systemData": {
                        "createdAt": "2020-02-20 00:00:00",
                        "createdBy": "str",
                        "createdByType": "str",
                        "lastModifiedAt": "2020-02-20 00:00:00",
                        "lastModifiedBy": "str",
                        "lastModifiedByType": "str",
                    },
                    "type": "str",
                },
                api_version="2025-06-30",
            )
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_database_migrations_sql_db_begin_delete(self, resource_group):
        response = await (
            await self.client.database_migrations_sql_db.begin_delete(
                resource_group_name=resource_group.name,
                sql_db_instance_name="str",
                target_db_name="str",
                api_version="2025-06-30",
            )
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_database_migrations_sql_db_begin_cancel(self, resource_group):
        response = await (
            await self.client.database_migrations_sql_db.begin_cancel(
                resource_group_name=resource_group.name,
                sql_db_instance_name="str",
                target_db_name="str",
                parameters={"migrationOperationId": "str"},
                api_version="2025-06-30",
            )
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy_async
    async def test_database_migrations_sql_db_begin_retry(self, resource_group):
        response = await (
            await self.client.database_migrations_sql_db.begin_retry(
                resource_group_name=resource_group.name,
                sql_db_instance_name="str",
                target_db_name="str",
                migration_operation_input={"migrationOperationId": "str"},
                api_version="2025-06-30",
            )
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.deviceregistry import DeviceRegistryMgmtClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestDeviceRegistryMgmtNamespaceDevicesOperations(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(DeviceRegistryMgmtClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_namespace_devices_get(self, resource_group):
        response = self.client.namespace_devices.get(
            resource_group_name=resource_group.name,
            namespace_name="str",
            device_name="str",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_namespace_devices_begin_create_or_replace(self, resource_group):
        response = self.client.namespace_devices.begin_create_or_replace(
            resource_group_name=resource_group.name,
            namespace_name="str",
            device_name="str",
            resource={
                "location": "str",
                "etag": "str",
                "extendedLocation": {"name": "str", "type": "str"},
                "id": "str",
                "name": "str",
                "properties": {
                    "attributes": {"str": {}},
                    "discoveredDeviceRef": "str",
                    "enabled": bool,
                    "endpoints": {
                        "inbound": {
                            "str": {
                                "address": "str",
                                "endpointType": "str",
                                "additionalConfiguration": "str",
                                "authentication": {
                                    "method": "str",
                                    "usernamePasswordCredentials": {
                                        "passwordSecretName": "str",
                                        "usernameSecretName": "str",
                                    },
                                    "x509Credentials": {
                                        "certificateSecretName": "str",
                                        "intermediateCertificatesSecretName": "str",
                                        "keySecretName": "str",
                                    },
                                },
                                "trustSettings": {"trustList": "str"},
                                "version": "str",
                            }
                        },
                        "outbound": {
                            "assigned": {"str": {"address": "str", "endpointType": "str"}},
                            "unassigned": {"str": {"address": "str", "endpointType": "str"}},
                        },
                    },
                    "externalDeviceId": "str",
                    "lastTransitionTime": "2020-02-20 00:00:00",
                    "manufacturer": "str",
                    "model": "str",
                    "operatingSystem": "str",
                    "operatingSystemVersion": "str",
                    "policy": {"resourceId": "str"},
                    "provisioningState": "str",
                    "status": {
                        "config": {
                            "error": {
                                "code": "str",
                                "details": [{"code": "str", "correlationId": "str", "info": "str", "message": "str"}],
                                "message": "str",
                            },
                            "lastTransitionTime": "2020-02-20 00:00:00",
                            "version": 0,
                        },
                        "endpoints": {
                            "inbound": {
                                "str": {
                                    "error": {
                                        "code": "str",
                                        "details": [
                                            {"code": "str", "correlationId": "str", "info": "str", "message": "str"}
                                        ],
                                        "message": "str",
                                    }
                                }
                            }
                        },
                    },
                    "uuid": "str",
                    "version": 0,
                },
                "systemData": {
                    "createdAt": "2020-02-20 00:00:00",
                    "createdBy": "str",
                    "createdByType": "str",
                    "lastModifiedAt": "2020-02-20 00:00:00",
                    "lastModifiedBy": "str",
                    "lastModifiedByType": "str",
                },
                "tags": {"str": "str"},
                "type": "str",
            },
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_namespace_devices_begin_update(self, resource_group):
        response = self.client.namespace_devices.begin_update(
            resource_group_name=resource_group.name,
            namespace_name="str",
            device_name="str",
            properties={
                "properties": {
                    "attributes": {"str": {}},
                    "enabled": bool,
                    "endpoints": {
                        "inbound": {
                            "str": {
                                "address": "str",
                                "endpointType": "str",
                                "additionalConfiguration": "str",
                                "authentication": {
                                    "method": "str",
                                    "usernamePasswordCredentials": {
                                        "passwordSecretName": "str",
                                        "usernameSecretName": "str",
                                    },
                                    "x509Credentials": {
                                        "certificateSecretName": "str",
                                        "intermediateCertificatesSecretName": "str",
                                        "keySecretName": "str",
                                    },
                                },
                                "trustSettings": {"trustList": "str"},
                                "version": "str",
                            }
                        },
                        "outbound": {
                            "assigned": {"str": {"address": "str", "endpointType": "str"}},
                            "unassigned": {"str": {"address": "str", "endpointType": "str"}},
                        },
                    },
                    "operatingSystemVersion": "str",
                    "policy": {"resourceId": "str"},
                },
                "tags": {"str": "str"},
            },
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_namespace_devices_begin_delete(self, resource_group):
        response = self.client.namespace_devices.begin_delete(
            resource_group_name=resource_group.name,
            namespace_name="str",
            device_name="str",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_namespace_devices_list_by_resource_group(self, resource_group):
        response = self.client.namespace_devices.list_by_resource_group(
            resource_group_name=resource_group.name,
            namespace_name="str",
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_namespace_devices_begin_revoke(self, resource_group):
        response = self.client.namespace_devices.begin_revoke(
            resource_group_name=resource_group.name,
            namespace_name="str",
            device_name="str",
            body={"disable": bool},
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...



# pylint: disable=line-too-long,useless-suppression
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.identity import DefaultAzureCredential

from azure.mgmt.dellstorage import DellStorageMgmtClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-dellstorage
# USAGE
    python file_systems_update_maximum_set_gen.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = DellStorageMgmtClient(
        credential=DefaultAzureCredential(),
        subscription_id="SUBSCRIPTION_ID",
    )

    response = client.file_systems.update(
        resource_group_name="rgDell",
        filesystem_name="abcd",
        properties={
            "identity": {"type": "SystemAssigned,UserAssigned", "userAssignedIdentities": {"key7645": {}}},
            "properties": {
                "capacity": {"current": "5"},
                "delegatedSubnetId": "bfpuabdz",
                "encryption": {
                    "encryptionIdentityProperties": {
                        "identityResourceId": "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ManagedIdentity/userAssignedIdentities/{identityName}",
                        "identityType": "UserAssigned",
                    },
                    "encryptionType": "Customer-managed keys (CMK)",
                    "keyUrl": "https://contoso.com/keyurl/keyVersion",
                },
            },
            "tags": {"key6099": "ursbxlphfcguvntuevleacwq"},
        },
    )
    print(response)


# x-ms-original-file: 2025-03-21/FileSystems_Update_MaximumSet_Gen.json
if __name__ == "__main__":
    main()



# pylint: disable=line-too-long,useless-suppression
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.identity import DefaultAzureCredential

from azure.mgmt.compute import ComputeManagementClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-compute
# USAGE
    python gallery_image_version_create_with_additional_replica_sets.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = ComputeManagementClient(
        credential=DefaultAzureCredential(),
        subscription_id="SUBSCRIPTION_ID",
    )

    response = client.gallery_image_versions.begin_create_or_update(
        resource_group_name="myResourceGroup",
        gallery_name="myGalleryName",
        gallery_image_name="myGalleryImageName",
        gallery_image_version_name="1.0.0",
        gallery_image_version={
            "location": "West US",
            "properties": {
                "publishingProfile": {
                    "targetRegions": [
                        {
                            "additionalReplicaSets": [
                                {"regionalReplicaCount": 1, "storageAccountType": "PreviumV2_LRS"}
                            ],
                            "encryption": {
                                "dataDiskImages": [
                                    {
                                        "diskEncryptionSetId": "/subscriptions/{subscriptionId}/resourceGroups/myResourceGroup/providers/Microsoft.Compute/diskEncryptionSet/myOtherWestUSDiskEncryptionSet",
                                        "lun": 0,
                                    },
                                    {
                                        "diskEncryptionSetId": "/subscriptions/{subscriptionId}/resourceGroups/myResourceGroup/providers/Microsoft.Compute/diskEncryptionSet/myWestUSDiskEncryptionSet",
                                        "lun": 1,
                                    },
                                ],
                                "osDiskImage": {
                                    "diskEncryptionSetId": "/subscriptions/{subscriptionId}/resourceGroups/myResourceGroup/providers/Microsoft.Compute/diskEncryptionSet/myWestUSDiskEncryptionSet"
                                },
                            },
                            "excludeFromLatest": False,
                            "name": "West US",
                            "regionalReplicaCount": 1,
                        },
                        {
                            "encryption": {
                                "dataDiskImages": [
                                    {
                                        "diskEncryptionSetId": "/subscriptions/{subscriptionId}/resourceGroups/myResourceGroup/providers/Microsoft.Compute/diskEncryptionSet/myOtherEastUSDiskEncryptionSet",
                                        "lun": 0,
                                    },
                                    {
                                        "diskEncryptionSetId": "/subscriptions/{subscriptionId}/resourceGroups/myResourceGroup/providers/Microsoft.Compute/diskEncryptionSet/myEastUSDiskEncryptionSet",
                                        "lun": 1,
                                    },
                                ],
                                "osDiskImage": {
                                    "diskEncryptionSetId": "/subscriptions/{subscriptionId}/resourceGroups/myResourceGroup/providers/Microsoft.Compute/diskEncryptionSet/myEastUSDiskEncryptionSet"
                                },
                            },
                            "excludeFromLatest": False,
                            "name": "East US",
                            "regionalReplicaCount": 2,
                            "storageAccountType": "Standard_ZRS",
                        },
                    ]
                },
                "safetyProfile": {"allowDeletionOfReplicatedLocations": False},
                "storageProfile": {
                    "source": {
                        "id": "/subscriptions/{subscriptionId}/resourceGroups/{resourceGroup}/providers/Microsoft.Compute/images/{imageName}"
                    }
                },
            },
        },
    ).result()
    print(response)


# x-ms-original-file: 2025-03-03/galleryExamples/GalleryImageVersion_Create_WithAdditionalReplicaSets.json
if __name__ == "__main__":
    main()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import

from ._operations import Operations  # type: ignore
from ._operations import FactoriesOperations  # type: ignore
from ._operations import ExposureControlOperations  # type: ignore
from ._operations import PipelineRunsOperations  # type: ignore
from ._operations import ActivityRunsOperations  # type: ignore
from ._operations import TriggersOperations  # type: ignore
from ._operations import TriggerRunsOperations  # type: ignore
from ._operations import DataFlowDebugSessionOperations  # type: ignore
from ._operations import PrivateLinkResourcesOperations  # type: ignore
from ._operations import IntegrationRuntimesOperations  # type: ignore
from ._operations import IntegrationRuntimeObjectMetadataOperations  # type: ignore
from ._operations import IntegrationRuntimeNodesOperations  # type: ignore
from ._operations import IntegrationRuntimeOperations  # type: ignore
from ._operations import LinkedServicesOperations  # type: ignore
from ._operations import DatasetsOperations  # type: ignore
from ._operations import PipelinesOperations  # type: ignore
from ._operations import DataFlowsOperations  # type: ignore
from ._operations import ManagedVirtualNetworksOperations  # type: ignore
from ._operations import ManagedPrivateEndpointsOperations  # type: ignore
from ._operations import CredentialOperationsOperations  # type: ignore
from ._operations import PrivateEndpointConnectionOperations  # type: ignore
from ._operations import PrivateEndPointConnectionsOperations  # type: ignore
from ._operations import GlobalParametersOperations  # type: ignore
from ._operations import ChangeDataCaptureOperations  # type: ignore

from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "Operations",
    "FactoriesOperations",
    "ExposureControlOperations",
    "PipelineRunsOperations",
    "ActivityRunsOperations",
    "TriggersOperations",
    "TriggerRunsOperations",
    "DataFlowDebugSessionOperations",
    "PrivateLinkResourcesOperations",
    "IntegrationRuntimesOperations",
    "IntegrationRuntimeObjectMetadataOperations",
    "IntegrationRuntimeNodesOperations",
    "IntegrationRuntimeOperations",
    "LinkedServicesOperations",
    "DatasetsOperations",
    "PipelinesOperations",
    "DataFlowsOperations",
    "ManagedVirtualNetworksOperations",
    "ManagedPrivateEndpointsOperations",
    "CredentialOperationsOperations",
    "PrivateEndpointConnectionOperations",
    "PrivateEndPointConnectionsOperations",
    "GlobalParametersOperations",
    "ChangeDataCaptureOperations",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()



# pylint: disable=line-too-long,useless-suppression
# ------------------------------------
# Copyright (c) Microsoft Corporation.
# Licensed under the MIT License.
# ------------------------------------
import json
import logging
import sys
from pathlib import Path

import pytest

SAMPLES_EVALUATIONS_DIR = Path(__file__).resolve().parents[1] / ".." / "samples" / "evaluations"
sys.path.insert(0, str(SAMPLES_EVALUATIONS_DIR.resolve()))

from sample_human_evaluations import (
    emit_5_point_ordinal_evaluation,
    emit_boolean_evaluation,
)  # noqa: E402


class _RecordCapture(logging.Handler):
    """Capture emitted ``LogRecord`` instances so tests can inspect ``extra=`` attributes."""

    def __init__(self) -> None:
        super().__init__(level=logging.DEBUG)
        self.records: list[logging.LogRecord] = []

    def emit(self, record: logging.LogRecord) -> None:
        self.records.append(record)


@pytest.fixture(autouse=True)
def capture():
    logger = logging.getLogger("human_evaluations")
    handler = _RecordCapture()
    logger.addHandler(handler)
    try:
        yield handler
    finally:
        logger.removeHandler(handler)


def _only_attrs(capture: _RecordCapture) -> dict:
    assert len(capture.records) == 1, f"expected exactly 1 emitted record, got {len(capture.records)}"
    return capture.records[0].__dict__


def _internal_properties(attrs: dict) -> dict:
    raw = attrs["internal_properties"]
    assert isinstance(raw, str)
    return json.loads(raw)


def test_boolean_failed_emits_score_0_with_fail_label(capture):
    emit_boolean_evaluation(evaluation_metric_name="task_completion", passed=False)
    attrs = _only_attrs(capture)
    assert attrs["gen_ai.evaluation.score.label"] == "fail"
    assert attrs["gen_ai.evaluation.score.value"] == 0.0


def test_boolean_passed_emits_score_1_with_pass_label(capture):
    emit_boolean_evaluation(evaluation_metric_name="task_completion", passed=True)
    attrs = _only_attrs(capture)
    assert attrs["gen_ai.evaluation.score.label"] == "pass"
    assert attrs["gen_ai.evaluation.score.value"] == 1.0


@pytest.mark.parametrize(
    "score_value, expected_label",
    [
        (1.0, "fail"),
        (3.0, "pass"),
        (5.0, "pass"),
    ],
)
def test_ordinal_score_emits_expected_label(capture, score_value, expected_label):
    emit_5_point_ordinal_evaluation(evaluation_metric_name="relevance", score_value=score_value)
    attrs = _only_attrs(capture)
    assert attrs["gen_ai.evaluation.score.label"] == expected_label
    assert attrs["gen_ai.evaluation.score.value"] == score_value


def test_ordinal_custom_threshold_controls_label_and_flows_to_internal_properties(
    capture,
):
    emit_5_point_ordinal_evaluation(evaluation_metric_name="relevance", score_value=2.0, threshold=4.0)
    attrs = _only_attrs(capture)
    decoded = _internal_properties(attrs)
    assert attrs["gen_ai.evaluation.score.label"] == "fail"
    assert decoded["gen_ai.evaluation.threshold"] == "4.0"


def test_ordinal_non_integer_score_raises():
    with pytest.raises(ValueError):
        emit_5_point_ordinal_evaluation(evaluation_metric_name="relevance", score_value=2.5)


@pytest.mark.parametrize("score_value", [0.0, 6.0])
def test_ordinal_score_out_of_range_raises(score_value):
    with pytest.raises(ValueError):
        emit_5_point_ordinal_evaluation(evaluation_metric_name="relevance", score_value=score_value)


@pytest.mark.parametrize("threshold", [0.0, 6.0])
def test_ordinal_threshold_out_of_range_raises(threshold):
    with pytest.raises(ValueError):
        emit_5_point_ordinal_evaluation(evaluation_metric_name="relevance", score_value=4.0, threshold=threshold)


def test_top_level_attributes_have_canonical_keys_and_routing(capture):
    emit_boolean_evaluation(evaluation_metric_name="task_completion", passed=True)
    attrs = _only_attrs(capture)
    assert attrs["microsoft.custom_event.name"] == "gen_ai.evaluation.result"
    assert attrs["gen_ai.evaluation.name"] == "task_completion"
    assert attrs["gen_ai.evaluation.score.value"] == 1.0
    assert attrs["gen_ai.evaluation.score.label"] == "pass"
    assert attrs["microsoft.gen_ai.human_evaluation.source"] == "end_user"
    assert attrs["microsoft.gen_ai.evaluation.actor.type"] == "human"
    assert "internal_properties" in attrs


def test_internal_properties_is_json_encoded_string_with_boolean_defaults(capture):
    emit_boolean_evaluation(evaluation_metric_name="task_completion", passed=True)
    decoded = _internal_properties(_only_attrs(capture))
    assert decoded["gen_ai.evaluation.threshold"] == "1.0"
    assert decoded["gen_ai.evaluation.min_value"] == "0.0"
    assert decoded["gen_ai.evaluation.max_value"] == "1.0"
    assert decoded["gen_ai.evaluation.desirable_direction"] == "increase"
    assert decoded["gen_ai.evaluation.type"] == "boolean"


def test_internal_properties_ordinal_defaults(capture):
    emit_5_point_ordinal_evaluation(evaluation_metric_name="relevance", score_value=4.0)
    decoded = _internal_properties(_only_attrs(capture))
    assert decoded["gen_ai.evaluation.threshold"] == "3.0"
    assert decoded["gen_ai.evaluation.min_value"] == "1.0"
    assert decoded["gen_ai.evaluation.max_value"] == "5.0"
    assert decoded["gen_ai.evaluation.desirable_direction"] == "increase"
    assert decoded["gen_ai.evaluation.type"] == "ordinal"


def test_response_id_set_adds_top_level_id(capture):
    emit_boolean_evaluation(
        evaluation_metric_name="task_completion",
        passed=True,
        response_id="resp_abc123",
    )
    attrs = _only_attrs(capture)
    assert attrs["gen_ai.response.id"] == "resp_abc123"


def test_response_id_omitted_omits_top_level_id(capture):
    emit_boolean_evaluation(evaluation_metric_name="task_completion", passed=True)
    attrs = _only_attrs(capture)
    assert "gen_ai.response.id" not in attrs


def test_conversation_id_set_adds_top_level_id(capture):
    emit_boolean_evaluation(
        evaluation_metric_name="task_completion",
        passed=True,
        conversation_id="conv_abc123",
    )
    attrs = _only_attrs(capture)
    assert attrs["gen_ai.conversation.id"] == "conv_abc123"


def test_saved_trace_context_is_current_while_emitting(capture):
    from opentelemetry import trace

    trace_id = "4bf92f3577b34da6a3ce929d0e0e4736"
    span_id = "00f067aa0ba902b7"
    captured_contexts = []

    class _ContextCapture(logging.Handler):
        def emit(self, record: logging.LogRecord) -> None:
            captured_contexts.append(trace.get_current_span().get_span_context())

    logger = logging.getLogger("human_evaluations")
    handler = _ContextCapture()
    logger.addHandler(handler)
    try:
        emit_boolean_evaluation(
            evaluation_metric_name="task_completion",
            passed=True,
            trace_id=trace_id,
            span_id=span_id,
        )
    finally:
        logger.removeHandler(handler)

    _only_attrs(capture)
    assert len(captured_contexts) == 1
    assert captured_contexts[0].trace_id == int(trace_id, 16)
    assert captured_contexts[0].span_id == int(span_id, 16)


@pytest.mark.parametrize(
    "trace_id, span_id",
    [
        ("4bf92f3577b34da6a3ce929d0e0e4736", None),
        (None, "00f067aa0ba902b7"),
    ],
)
def test_trace_id_and_span_id_must_be_provided_together(trace_id, span_id):
    with pytest.raises(ValueError):
        emit_boolean_evaluation(
            evaluation_metric_name="task_completion",
            passed=True,
            trace_id=trace_id,
            span_id=span_id,
        )


def test_project_resource_id_set_added_to_internal_properties(capture):
    arm_id = (
        "/subscriptions/sub-id/resourceGroups/rg/providers/Microsoft.CognitiveServices" "/accounts/acct/projects/proj"
    )
    emit_boolean_evaluation(
        evaluation_metric_name="task_completion",
        passed=True,
        project_resource_id=arm_id,
    )
    decoded = _internal_properties(_only_attrs(capture))
    assert decoded["gen_ai.azure_ai_project.id"] == arm_id


def test_project_resource_id_omitted_omits_key(capture):
    emit_boolean_evaluation(evaluation_metric_name="task_completion", passed=True)
    decoded = _internal_properties(_only_attrs(capture))
    assert "gen_ai.azure_ai_project.id" not in decoded


def test_enduser_id_only_sets_only_authenticated_attribute(capture):
    emit_boolean_evaluation(
        evaluation_metric_name="task_completion",
        passed=True,
        enduser_id="user-oid-123",
    )
    attrs = _only_attrs(capture)
    assert attrs["enduser.id"] == "user-oid-123"
    assert "enduser.pseudo.id" not in attrs


def test_enduser_pseudo_id_only_sets_only_pseudo_attribute(capture):
    emit_boolean_evaluation(
        evaluation_metric_name="task_completion",
        passed=True,
        enduser_pseudo_id="sess_abc",
    )
    attrs = _only_attrs(capture)
    assert attrs["enduser.pseudo.id"] == "sess_abc"
    assert "enduser.id" not in attrs


def test_both_enduser_ids_set_both_attributes(capture):
    emit_boolean_evaluation(
        evaluation_metric_name="task_completion",
        passed=True,
        enduser_id="user-oid-123",
        enduser_pseudo_id="sess_abc",
    )
    attrs = _only_attrs(capture)
    assert attrs["enduser.id"] == "user-oid-123"
    assert attrs["enduser.pseudo.id"] == "sess_abc"


def test_tags_fan_out_as_top_level_attributes(capture):
    emit_boolean_evaluation(
        evaluation_metric_name="task_completion",
        passed=True,
        tags={"subscription_tier": "basic_plan", "department": "marketing"},
    )
    attrs = _only_attrs(capture)
    assert attrs["microsoft.gen_ai.evaluation.tags.subscription_tier"] == "basic_plan"
    assert attrs["microsoft.gen_ai.evaluation.tags.department"] == "marketing"


def test_evaluation_id_omitted_omits_attribute(capture):
    emit_boolean_evaluation(evaluation_metric_name="task_completion", passed=True)
    attrs = _only_attrs(capture)
    assert "microsoft.gen_ai.human_evaluation.id" not in attrs


def test_evaluation_id_provided_flows_through_verbatim_as_top_level_attribute(capture):
    emit_boolean_evaluation(
        evaluation_metric_name="task_completion",
        passed=True,
        evaluation_id="custom-eval-id-42",
    )
    attrs = _only_attrs(capture)
    assert attrs["microsoft.gen_ai.human_evaluation.id"] == "custom-eval-id-42"


def test_explanation_flows_through_as_top_level_attribute(capture):
    emit_boolean_evaluation(
        evaluation_metric_name="task_completion",
        passed=True,
        explanation="The agent answered correctly.",
    )
    attrs = _only_attrs(capture)
    assert attrs["gen_ai.evaluation.explanation"] == "The agent answered correctly."


def test_explanation_omitted_omits_attribute(capture):
    emit_boolean_evaluation(evaluation_metric_name="task_completion", passed=True)
    attrs = _only_attrs(capture)
    assert "gen_ai.evaluation.explanation" not in attrs



# pylint: disable=line-too-long,useless-suppression
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.identity import DefaultAzureCredential

from azure.mgmt.compute import ComputeManagementClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-compute
# USAGE
    python virtual_machine_run_command_create_or_update.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = ComputeManagementClient(
        credential=DefaultAzureCredential(),
        subscription_id="SUBSCRIPTION_ID",
    )

    response = client.virtual_machine_run_commands.begin_create_or_update(
        resource_group_name="myResourceGroup",
        vm_name="myVM",
        run_command_name="myRunCommand",
        run_command={
            "location": "West US",
            "properties": {
                "asyncExecution": False,
                "errorBlobUri": "https://mystorageaccount.blob.core.windows.net/scriptcontainer/scriptURI",
                "outputBlobManagedIdentity": {"clientId": "22d35efb-0c99-4041-8c5b-6d24db33a69a"},
                "outputBlobUri": "https://mystorageaccount.blob.core.windows.net/myscriptoutputcontainer/MyScriptoutput.txt",
                "parameters": [{"name": "param1", "value": "value1"}, {"name": "param2", "value": "value2"}],
                "runAsPassword": "<runAsPassword>",
                "runAsUser": "user1",
                "source": {"scriptUri": "https://mystorageaccount.blob.core.windows.net/scriptcontainer/scriptURI"},
                "timeoutInSeconds": 3600,
                "treatFailureAsDeploymentFailure": False,
            },
        },
    ).result()
    print(response)


# x-ms-original-file: 2025-11-01/runCommandExamples/VirtualMachineRunCommand_CreateOrUpdate.json
if __name__ == "__main__":
    main()



# coding: utf-8
# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

import pytest
import unittest
from datetime import datetime, timedelta, timezone
from unittest.mock import MagicMock
from azure.core.exceptions import HttpResponseError

import azure.communication.identity._shared.token_utils as utils

from azure.communication.identity._shared.token_utils import (
    TEAMS_EXTENSION_SCOPE_PREFIX,
    COMMUNICATION_CLIENTS_SCOPE_PREFIX,
    TEAMS_EXTENSION_ENDPOINT,
    TEAMS_EXTENSION_API_VERSION,
    COMMUNICATION_CLIENTS_ENDPOINT,
    COMMUNICATION_CLIENTS_API_VERSION,
)


class DummyResponse:
    def __init__(self, status_code=200, expires_on=None):
        self.http_response = MagicMock()
        self.http_response.status_code = status_code
        self.http_response.text.return_value = (
            '{"accessToken": {"expiresOn": "%s"}}' % expires_on
            if expires_on else '{}'
        )


class TestTokenUtils(unittest.TestCase):
    def test_is_entra_token_cache_valid(self):
        request = MagicMock()
        request.http_request.headers = {"Authorization": "token"}
        valid, token = utils.is_entra_token_cache_valid("token", request)
        self.assertTrue(valid)
        self.assertEqual(token, "token")

        valid, token = utils.is_entra_token_cache_valid("other", request)
        self.assertFalse(valid)
        self.assertEqual(token, "token")

    def test_is_acs_token_cache_valid(self):
        # Valid response
        expires_on = (datetime.now(timezone.utc) + timedelta(minutes=5)).isoformat()
        response = DummyResponse(status_code=200, expires_on=expires_on)
        self.assertTrue(utils.is_acs_token_cache_valid(response))

        # Expired token
        expires_on = (datetime.now(timezone.utc) - timedelta(minutes=5)).isoformat()
        response = DummyResponse(status_code=200, expires_on=expires_on)
        self.assertFalse(utils.is_acs_token_cache_valid(response))

        # Invalid response
        response = DummyResponse(status_code=400)
        self.assertFalse(utils.is_acs_token_cache_valid(response))

        # Exception in parsing
        response = DummyResponse(status_code=200)
        response.http_response.text.return_value = "not json"
        with self.assertRaises(Exception):
            utils.is_acs_token_cache_valid(response)

    def test_create_request_message_and_uri(self):
        uri = utils.create_request_uri("https://endpoint", [TEAMS_EXTENSION_SCOPE_PREFIX + ".default"])
        assert uri.startswith("https://endpoint")
        assert TEAMS_EXTENSION_ENDPOINT in uri

        req = utils.create_request_message("https://endpoint",
                                                         [TEAMS_EXTENSION_SCOPE_PREFIX + ".default"])
        assert req.method == "POST"
        assert req.headers["Accept"] == "application/json"
        assert req.headers["Content-Type"] == "application/json"

    def test_determine_endpoint_and_api_version_teams_extension(self):
        endpoint, api_version = utils.determine_endpoint_and_api_version(
            [TEAMS_EXTENSION_SCOPE_PREFIX + ".default"])
        assert endpoint == TEAMS_EXTENSION_ENDPOINT
        assert api_version == TEAMS_EXTENSION_API_VERSION

    def test_determine_endpoint_and_api_version_communication_clients(self):
        endpoint, api_version = utils.determine_endpoint_and_api_version(
            [COMMUNICATION_CLIENTS_SCOPE_PREFIX + ".default"])
        assert endpoint == COMMUNICATION_CLIENTS_ENDPOINT
        assert api_version == COMMUNICATION_CLIENTS_API_VERSION

    def test_determine_endpoint_and_api_version_invalid_scope(self):
        with pytest.raises(ValueError):
            utils.determine_endpoint_and_api_version(["invalid-scope"])

    def test_parse_expires_on_iso_string(self):
        epoch = utils.parse_expires_on("2999-12-31T23:59:59Z", MagicMock())
        assert isinstance(epoch, int)

    def test_parse_expires_on_invalid_type(self):
        with pytest.raises(HttpResponseError):
            utils.parse_expires_on(None, MagicMock())

    def test_parse_expires_on_invalid_string(self):
        with pytest.raises(HttpResponseError):
            utils.parse_expires_on("invalid-date", MagicMock())



# coding=utf-8
# ------------------------------------
# Copyright (c) Microsoft.
# Licensed under the MIT License.
# ------------------------------------

"""
FILE: sample_get_project.py
DESCRIPTION:
    This sample demonstrates how to get a **Text Authoring** project and print its details.
USAGE:
    python sample_get_project.py
REQUIRED ENV VARS (for AAD / DefaultAzureCredential):
    AZURE_TEXT_ENDPOINT
    AZURE_CLIENT_ID
    AZURE_TENANT_ID
    AZURE_CLIENT_SECRET
NOTE:
    If you want to use AzureKeyCredential instead, set:
      - AZURE_TEXT_ENDPOINT
      - AZURE_TEXT_KEY
OPTIONAL ENV VARS:
    PROJECT_NAME  # defaults to "<project-name>"
"""

# [START text_authoring_get_project]
import os
from azure.identity import DefaultAzureCredential
from azure.ai.textanalytics.authoring import TextAuthoringClient


def sample_get_project():
    # settings
    endpoint = os.environ["AZURE_TEXT_ENDPOINT"]
    project_name = os.environ.get("PROJECT_NAME", "<project-name>")

    # create a client with AAD
    credential = DefaultAzureCredential()
    client = TextAuthoringClient(endpoint, credential=credential)

    # get project
    result = client.get_project(project_name)

    # print project details (direct attribute access; no getattr)
    print("=== Project Details ===")
    print(f"  name: {result.project_name}")
    print(f"  language: {result.language}")
    print(f"  created: {result.created_on}")
    print(f"  last modified: {result.last_modified_on}")
    print(f"  storage container: {result.storage_input_container_name}")


# [END text_authoring_get_project]


def main():
    sample_get_project()


if __name__ == "__main__":
    main()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
import pytest
from azure.mgmt.containerinstance import ContainerInstanceManagementClient

from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy

AZURE_LOCATION = "eastus"


@pytest.mark.skip("you may need to update the auto-generated test case before run it")
class TestContainerInstanceManagementContainerGroupsOperations(AzureMgmtRecordedTestCase):
    def setup_method(self, method):
        self.client = self.create_mgmt_client(ContainerInstanceManagementClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_container_groups_get(self, resource_group):
        response = self.client.container_groups.get(
            resource_group_name=resource_group.name,
            container_group_name="str",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_container_groups_begin_create_or_update(self, resource_group):
        response = self.client.container_groups.begin_create_or_update(
            resource_group_name=resource_group.name,
            container_group_name="str",
            container_group={
                "properties": {
                    "containers": [
                        {
                            "name": "str",
                            "properties": {
                                "command": ["str"],
                                "configMap": {"keyValuePairs": {"str": "str"}},
                                "environmentVariables": [
                                    {"name": "str", "secureValue": "str", "secureValueReference": "str", "value": "str"}
                                ],
                                "image": "str",
                                "instanceView": {
                                    "currentState": {
                                        "detailStatus": "str",
                                        "exitCode": 0,
                                        "finishTime": "2020-02-20 00:00:00",
                                        "startTime": "2020-02-20 00:00:00",
                                        "state": "str",
                                    },
                                    "events": [
                                        {
                                            "count": 0,
                                            "firstTimestamp": "2020-02-20 00:00:00",
                                            "lastTimestamp": "2020-02-20 00:00:00",
                                            "message": "str",
                                            "name": "str",
                                            "type": "str",
                                        }
                                    ],
                                    "previousState": {
                                        "detailStatus": "str",
                                        "exitCode": 0,
                                        "finishTime": "2020-02-20 00:00:00",
                                        "startTime": "2020-02-20 00:00:00",
                                        "state": "str",
                                    },
                                    "restartCount": 0,
                                },
                                "livenessProbe": {
                                    "exec": {"command": ["str"]},
                                    "failureThreshold": 0,
                                    "httpGet": {
                                        "port": 0,
                                        "httpHeaders": [{"name": "str", "value": "str"}],
                                        "path": "str",
                                        "scheme": "str",
                                    },
                                    "initialDelaySeconds": 0,
                                    "periodSeconds": 0,
                                    "successThreshold": 0,
                                    "timeoutSeconds": 0,
                                },
                                "ports": [{"port": 0, "protocol": "str"}],
                                "readinessProbe": {
                                    "exec": {"command": ["str"]},
                                    "failureThreshold": 0,
                                    "httpGet": {
                                        "port": 0,
                                        "httpHeaders": [{"name": "str", "value": "str"}],
                                        "path": "str",
                                        "scheme": "str",
                                    },
                                    "initialDelaySeconds": 0,
                                    "periodSeconds": 0,
                                    "successThreshold": 0,
                                    "timeoutSeconds": 0,
                                },
                                "resources": {
                                    "requests": {"cpu": 0.0, "memoryInGB": 0.0, "gpu": {"count": 0, "sku": "str"}},
                                    "limits": {"cpu": 0.0, "gpu": {"count": 0, "sku": "str"}, "memoryInGB": 0.0},
                                },
                                "securityContext": {
                                    "allowPrivilegeEscalation": bool,
                                    "capabilities": {"add": ["str"], "drop": ["str"]},
                                    "privileged": bool,
                                    "runAsGroup": 0,
                                    "runAsUser": 0,
                                    "seccompProfile": "str",
                                },
                                "volumeMounts": [{"mountPath": "str", "name": "str", "readOnly": bool}],
                            },
                        }
                    ],
                    "confidentialComputeProperties": {"ccePolicy": "str"},
                    "containerGroupProfile": {"id": "str", "revision": 0},
                    "diagnostics": {
                        "logAnalytics": {
                            "workspaceId": "str",
                            "workspaceKey": "str",
                            "logType": "str",
                            "metadata": {"str": "str"},
                            "workspaceResourceId": "str",
                        }
                    },
                    "dnsConfig": {"nameServers": ["str"], "options": "str", "searchDomains": "str"},
                    "encryptionProperties": {
                        "keyName": "str",
                        "keyVersion": "str",
                        "vaultBaseUrl": "str",
                        "identity": "str",
                    },
                    "extensions": [
                        {
                            "name": "str",
                            "properties": {
                                "extensionType": "str",
                                "version": "str",
                                "protectedSettings": {},
                                "settings": {},
                            },
                        }
                    ],
                    "identityAcls": {"acls": [{"access": "str", "identity": "str"}], "defaultAccess": "str"},
                    "imageRegistryCredentials": [
                        {
                            "server": "str",
                            "identity": "str",
                            "identityUrl": "str",
                            "password": "str",
                            "passwordReference": "str",
                            "username": "str",
                        }
                    ],
                    "initContainers": [
                        {
                            "name": "str",
                            "properties": {
                                "command": ["str"],
                                "environmentVariables": [
                                    {"name": "str", "secureValue": "str", "secureValueReference": "str", "value": "str"}
                                ],
                                "image": "str",
                                "instanceView": {
                                    "currentState": {
                                        "detailStatus": "str",
                                        "exitCode": 0,
                                        "finishTime": "2020-02-20 00:00:00",
                                        "startTime": "2020-02-20 00:00:00",
                                        "state": "str",
                                    },
                                    "events": [
                                        {
                                            "count": 0,
                                            "firstTimestamp": "2020-02-20 00:00:00",
                                            "lastTimestamp": "2020-02-20 00:00:00",
                                            "message": "str",
                                            "name": "str",
                                            "type": "str",
                                        }
                                    ],
                                    "previousState": {
                                        "detailStatus": "str",
                                        "exitCode": 0,
                                        "finishTime": "2020-02-20 00:00:00",
                                        "startTime": "2020-02-20 00:00:00",
                                        "state": "str",
                                    },
                                    "restartCount": 0,
                                },
                                "securityContext": {
                                    "allowPrivilegeEscalation": bool,
                                    "capabilities": {"add": ["str"], "drop": ["str"]},
                                    "privileged": bool,
                                    "runAsGroup": 0,
                                    "runAsUser": 0,
                                    "seccompProfile": "str",
                                },
                                "volumeMounts": [{"mountPath": "str", "name": "str", "readOnly": bool}],
                            },
                        }
                    ],
                    "instanceView": {
                        "events": [
                            {
                                "count": 0,
                                "firstTimestamp": "2020-02-20 00:00:00",
                                "lastTimestamp": "2020-02-20 00:00:00",
                                "message": "str",
                                "name": "str",
                                "type": "str",
                            }
                        ],
                        "state": "str",
                    },
                    "ipAddress": {
                        "ports": [{"port": 0, "protocol": "str"}],
                        "type": "str",
                        "autoGeneratedDomainNameLabelScope": "str",
                        "dnsNameLabel": "str",
                        "fqdn": "str",
                        "ip": "str",
                    },
                    "isCreatedFromStandbyPool": bool,
                    "osType": "str",
                    "priority": "str",
                    "provisioningState": "str",
                    "restartPolicy": "str",
                    "secretReferences": [{"identity": "str", "name": "str", "secretReferenceUri": "str"}],
                    "sku": "str",
                    "standbyPoolProfile": {"failContainerGroupCreateOnReuseFailure": bool, "id": "str"},
                    "subnetIds": [{"id": "str", "name": "str"}],
                    "volumes": [
                        {
                            "name": "str",
                            "azureFile": {
                                "shareName": "str",
                                "storageAccountName": "str",
                                "readOnly": bool,
                                "storageAccountKey": "str",
                                "storageAccountKeyReference": "str",
                            },
                            "emptyDir": {},
                            "gitRepo": {"repository": "str", "directory": "str", "revision": "str"},
                            "secret": {"str": "str"},
                            "secretReference": {"str": "str"},
                        }
                    ],
                },
                "id": "str",
                "identity": {
                    "principalId": "str",
                    "tenantId": "str",
                    "type": "str",
                    "userAssignedIdentities": {"str": {"clientId": "str", "principalId": "str"}},
                },
                "location": "str",
                "name": "str",
                "systemData": {
                    "createdAt": "2020-02-20 00:00:00",
                    "createdBy": "str",
                    "createdByType": "str",
                    "lastModifiedAt": "2020-02-20 00:00:00",
                    "lastModifiedBy": "str",
                    "lastModifiedByType": "str",
                },
                "tags": {"str": "str"},
                "type": "str",
                "zones": ["str"],
            },
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_container_groups_update(self, resource_group):
        response = self.client.container_groups.update(
            resource_group_name=resource_group.name,
            container_group_name="str",
            resource={
                "id": "str",
                "location": "str",
                "name": "str",
                "tags": {"str": "str"},
                "type": "str",
                "zones": ["str"],
            },
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_container_groups_begin_delete(self, resource_group):
        response = self.client.container_groups.begin_delete(
            resource_group_name=resource_group.name,
            container_group_name="str",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_container_groups_begin_restart(self, resource_group):
        response = self.client.container_groups.begin_restart(
            resource_group_name=resource_group.name,
            container_group_name="str",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_container_groups_stop(self, resource_group):
        response = self.client.container_groups.stop(
            resource_group_name=resource_group.name,
            container_group_name="str",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_container_groups_begin_start(self, resource_group):
        response = self.client.container_groups.begin_start(
            resource_group_name=resource_group.name,
            container_group_name="str",
        ).result()  # call '.result()' to poll until service return final result

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_container_groups_get_outbound_network_dependencies_endpoints(self, resource_group):
        response = self.client.container_groups.get_outbound_network_dependencies_endpoints(
            resource_group_name=resource_group.name,
            container_group_name="str",
        )

        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_container_groups_list(self, resource_group):
        response = self.client.container_groups.list()
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_container_groups_list_by_resource_group(self, resource_group):
        response = self.client.container_groups.list_by_resource_group(
            resource_group_name=resource_group.name,
        )
        result = [r for r in response]
        # please add some check logic here by yourself
        # ...



# pylint: disable=line-too-long,useless-suppression
import functools
import pytest

from devtools_testutils import AzureRecordedTestCase, EnvironmentVariableLoader
from devtools_testutils.aio import recorded_by_proxy_async
from azure.core.credentials import AzureKeyCredential
from azure.ai.textanalytics.authoring.aio import TextAuthoringClient
from azure.ai.textanalytics.authoring.models import (
    CustomSingleLabelClassificationEvalSummary,
    EvaluationDetails,
)

AuthoringPreparer = functools.partial(
    EnvironmentVariableLoader,
    "authoring",
    authoring_endpoint="https://Sanitized.cognitiveservices.azure.com/",
    authoring_key="fake_key",
)


class TestTextAuthoring(AzureRecordedTestCase):
    pass


class TestTextAuthoringGetModelEvaluationSummaryAsync(TestTextAuthoring):
    @AuthoringPreparer()
    @recorded_by_proxy_async
    @pytest.mark.asyncio
    async def test_get_model_evaluation_summary_async(self, authoring_endpoint, authoring_key):
        async with TextAuthoringClient(authoring_endpoint, AzureKeyCredential(authoring_key)) as client:
            project_name = "single-class-project"
            trained_model_label = "model3"

            # Trained-model–scoped call
            project_client = client.get_project_client(project_name)
            eval_summary = await project_client.trained_model.get_model_evaluation_summary(trained_model_label)

            # Assert the call returned something
            assert eval_summary is not None

            # Ensure we got a single-label classification evaluation summary
            assert isinstance(eval_summary, CustomSingleLabelClassificationEvalSummary)

            # Evaluation options must exist
            evaluation_options: EvaluationDetails = eval_summary.evaluation_options
            assert evaluation_options is not None
            print("Evaluation Options:")
            print(f"    Kind: {evaluation_options.kind}")
            print(f"    Training Split Percentage: {evaluation_options.training_split_percentage}")
            print(f"    Testing Split Percentage: {evaluation_options.testing_split_percentage}")

            # Classification evaluation must exist
            sl_eval = eval_summary.custom_single_label_classification_evaluation
            assert sl_eval is not None

            # Print micro/macro metrics
            print(f"Micro F1: {sl_eval.micro_f1}")
            print(f"Micro Precision: {sl_eval.micro_precision}")
            print(f"Micro Recall: {sl_eval.micro_recall}")
            print(f"Macro F1: {sl_eval.macro_f1}")
            print(f"Macro Precision: {sl_eval.macro_precision}")
            print(f"Macro Recall: {sl_eval.macro_recall}")

            # Confusion matrix
            cmatrix = sl_eval.confusion_matrix
            if cmatrix:
                print("Confusion Matrix:")
                for row_key, row_val in cmatrix.items():
                    print(f"Row: {row_key}")
                    for col_key, cell in row_val.items():
                        print(
                            f"    Column: {col_key}, Normalized Value: {cell['normalizedValue']}, Raw Value: {cell['rawValue']}"
                        )

            # Class-specific metrics
            classes_map = sl_eval.classes
            assert classes_map is not None and len(classes_map) > 0, "Class-specific metrics should not be empty."
            print("Class-Specific Metrics:")
            for cls_name, metrics in classes_map.items():
                print(f"Class: {cls_name}")
                print(f"    F1: {metrics.f1}")
                print(f"    Precision: {metrics.precision}")
                print(f"    Recall: {metrics.recall}")
                print(f"    True Positives: {metrics.true_positive_count}")
                print(f"    True Negatives: {metrics.true_negative_count}")
                print(f"    False Positives: {metrics.false_positive_count}")
                print(f"    False Negatives: {metrics.false_negative_count}")



# ------------------------------------
# Copyright (c) Microsoft Corporation.
# Licensed under the MIT License.
# ------------------------------------
"""
Tests verifying that instrumentors correctly skip non-recording spans.

When a span is not recording, the instrumentor must not attempt to write
attributes or events to it. These tests use a mock span whose
``is_recording()`` returns False and whose mutation methods raise
``AssertionError`` if called, ensuring the guards work correctly.
"""

import os
import json
import pytest
from unittest.mock import MagicMock, PropertyMock

from azure.ai.projects.telemetry._ai_project_instrumentor import (
    _AIAgentsInstrumentorPreview,
)
from azure.ai.projects.telemetry._responses_instrumentor import (
    _ResponsesInstrumentorPreview,
)


def _make_non_recording_span():
    """Return a mock AbstractSpan wrapping a non-recording OTel span.

    * ``span_instance.is_recording()`` returns ``False``
    * ``span_instance.is_recording`` (the property/method) also returns ``False``
      so the guard correctly skips writes.
    * Any call to ``add_event``, ``set_status``, ``record_exception`` or
      ``set_attribute`` raises ``AssertionError``, catching any code path
      that fails to check ``is_recording()`` properly.
    """
    span_instance = MagicMock()
    span_instance.is_recording = MagicMock(return_value=False)
    span_instance.add_event = MagicMock(side_effect=AssertionError("add_event called on non-recording span"))
    span_instance.set_status = MagicMock(side_effect=AssertionError("set_status called on non-recording span"))
    span_instance.record_exception = MagicMock(
        side_effect=AssertionError("record_exception called on non-recording span")
    )

    span = MagicMock()
    span.span_instance = span_instance
    span.add_attribute = MagicMock(side_effect=AssertionError("add_attribute called on non-recording span"))
    return span


class TestNonRecordingSpanProjectInstrumentor:
    """Verify _AIAgentsInstrumentorPreview skips non-recording spans."""

    def test_add_message_event_skips_non_recording_span(self):
        """_add_message_event should not write to a non-recording span."""
        instrumentor = _AIAgentsInstrumentorPreview()
        span = _make_non_recording_span()

        # This must not raise; the guard should return early.
        instrumentor._add_message_event(span, role="user", content="hello")

    def test_add_instructions_event_skips_non_recording_span(self):
        """_add_instructions_event should not write to a non-recording span."""
        instrumentor = _AIAgentsInstrumentorPreview()
        span = _make_non_recording_span()

        instrumentor._add_instructions_event(span, instructions="Be helpful", additional_instructions=None)

    def test_start_create_agent_span_skips_non_recording_span(self):
        """start_create_agent_span should not write attributes to a non-recording span."""
        instrumentor = _AIAgentsInstrumentorPreview()

        # We need to patch start_span to return our non-recording span
        from unittest.mock import patch

        non_recording_span = _make_non_recording_span()

        with patch(
            "azure.ai.projects.telemetry._ai_project_instrumentor.start_span",
            return_value=non_recording_span,
        ):
            result = instrumentor.start_create_agent_span(
                server_address="test.openai.azure.com",
                port=443,
                model="gpt-4",
                name="test-agent",
                instructions="Be helpful",
            )

        # Should return the span but not have written any attributes/events to it
        assert result is non_recording_span
        non_recording_span.add_attribute.assert_not_called()
        non_recording_span.span_instance.add_event.assert_not_called()


class TestNonRecordingSpanResponsesInstrumentor:
    """Verify _ResponsesInstrumentorPreview skips non-recording spans."""

    def test_set_span_attribute_safe_skips_non_recording_span(self):
        """_set_span_attribute_safe should not write to a non-recording span."""
        instrumentor = _ResponsesInstrumentorPreview()
        span = _make_non_recording_span()

        # This must not raise; the guard should return early.
        instrumentor._set_span_attribute_safe(span, "test.key", "test_value")

    def test_start_responses_span_skips_non_recording_span(self):
        """start_responses_span should not write attributes to a non-recording span."""
        instrumentor = _ResponsesInstrumentorPreview()

        from unittest.mock import patch

        non_recording_span = _make_non_recording_span()

        with patch(
            "azure.ai.projects.telemetry._responses_instrumentor.start_span",
            return_value=non_recording_span,
        ):
            result = instrumentor.start_responses_span(
                server_address="test.openai.azure.com",
                port=443,
                model="gpt-4",
                assistant_name="test-agent",
                conversation_id="conv-123",
                input_text="Hello",
            )

        assert result is non_recording_span
        non_recording_span.add_attribute.assert_not_called()
        non_recording_span.span_instance.add_event.assert_not_called()

    def test_start_create_conversation_span_skips_non_recording_span(self):
        """start_create_conversation_span should not write to a non-recording span."""
        instrumentor = _ResponsesInstrumentorPreview()

        from unittest.mock import patch

        non_recording_span = _make_non_recording_span()

        with patch(
            "azure.ai.projects.telemetry._responses_instrumentor.start_span",
            return_value=non_recording_span,
        ):
            result = instrumentor.start_create_conversation_span(
                server_address="test.openai.azure.com",
                port=443,
            )

        assert result is non_recording_span
        non_recording_span.add_attribute.assert_not_called()
        non_recording_span.span_instance.add_event.assert_not_called()

    def test_start_list_conversation_items_span_skips_non_recording_span(self):
        """start_list_conversation_items_span should not write to a non-recording span."""
        instrumentor = _ResponsesInstrumentorPreview()

        from unittest.mock import patch

        non_recording_span = _make_non_recording_span()

        with patch(
            "azure.ai.projects.telemetry._responses_instrumentor.start_span",
            return_value=non_recording_span,
        ):
            result = instrumentor.start_list_conversation_items_span(
                server_address="test.openai.azure.com",
                port=443,
                conversation_id="conv-123",
            )

        assert result is non_recording_span
        non_recording_span.add_attribute.assert_not_called()
        non_recording_span.span_instance.add_event.assert_not_called()

    def test_add_tool_call_events_skips_non_recording_span(self):
        """_add_tool_call_events should not write to a non-recording span."""
        instrumentor = _ResponsesInstrumentorPreview()
        span = _make_non_recording_span()

        # Create a mock response with function call output
        mock_response = MagicMock()
        mock_output_item = MagicMock()
        mock_output_item.type = "function_call"
        mock_output_item.name = "get_weather"
        mock_output_item.call_id = "call_123"
        mock_output_item.arguments = '{"city": "Seattle"}'
        mock_response.output = [mock_output_item]

        instrumentor._add_tool_call_events(span, mock_response)

    def test_add_conversation_item_event_skips_non_recording_span(self):
        """_add_conversation_item_event should not write to a non-recording span."""
        instrumentor = _ResponsesInstrumentorPreview()
        span = _make_non_recording_span()

        mock_item = MagicMock()
        mock_item.id = "item_123"
        mock_item.type = "message"
        mock_item.role = "user"
        mock_item.content = []

        instrumentor._add_conversation_item_event(span, mock_item)



# pylint: disable=line-too-long,useless-suppression
# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

"""
TEST FILE: test_sample_to_llm_input_async.py

DESCRIPTION:
    These tests validate the sample_to_llm_input_async.py sample code.

    The sample demonstrates four scenarios for the to_llm_input() helper:
      1. OUTPUT OPTIONS — fields-only, markdown-only, custom metadata
      2. MULTI-PAGE PDF WITH CONTENT RANGE — page markers preserve original numbers
      3. MULTI-SEGMENT VIDEO — segments separated by '*****', each with timeRange
      4. AUDIO WITH CONTENT RANGE — single segment with custom metadata

    Each test mirrors one section of the sample, exercising the same analyzer,
    URL, and to_llm_input options used in that section.

USAGE:
    pytest test_sample_to_llm_input_async.py
"""

from devtools_testutils.aio import recorded_by_proxy_async
from testpreparer_async import ContentUnderstandingPreparer, ContentUnderstandingClientTestBaseAsync
from azure.ai.contentunderstanding import to_llm_input
from azure.ai.contentunderstanding.models import (
    AnalysisInput,
    AudioVisualContent,
    DocumentContent,
)


class TestSampleToLlmInputAsync(ContentUnderstandingClientTestBaseAsync):
    """Tests for sample_to_llm_input_async.py"""

    @ContentUnderstandingPreparer()
    @recorded_by_proxy_async
    async def test_to_llm_input_output_options_async(self, contentunderstanding_endpoint: str) -> None:
        """Section 1 of the sample — output option flags and custom metadata.

        Validates:
        - Default output (fields + markdown) contains both
        - include_markdown=False produces fields-only output (no markdown body)
        - include_fields=False produces markdown-only output (no 'fields:' block)
        - metadata={...} injects custom keys into the YAML front matter
        """
        client = self.create_async_client(endpoint=contentunderstanding_endpoint)

        invoice_url = "https://raw.githubusercontent.com/Azure-Samples/azure-ai-content-understanding-assets/main/document/invoice.pdf"

        poller = await client.begin_analyze(
            analyzer_id="prebuilt-invoice",
            inputs=[AnalysisInput(url=invoice_url)],
        )
        result = await poller.result()

        assert result is not None and result.contents, "Analysis should return contents"
        content = result.contents[0]
        assert isinstance(content, DocumentContent), "Invoice analysis should return DocumentContent"
        markdown = content.markdown or ""
        assert markdown.strip(), "Invoice analysis should return non-empty markdown"
        print(f"[PASS] Invoice analyzed ({len(markdown)} markdown chars)")

        # --- Default: fields + markdown ---
        default_text = to_llm_input(result)
        assert default_text.startswith("---"), "Default output should start with YAML front matter"
        assert "\n---\n" in default_text, "Default output should close YAML front matter"
        assert "contentType: document" in default_text, "Default output should declare contentType: document"
        assert "fields:" in default_text, "Default output should include 'fields:' block"
        assert markdown in default_text, "Default output should include markdown body"
        print(f"[PASS] Default output: fields + markdown ({len(default_text)} chars)")

        # --- Fields-only: include_markdown=False ---
        fields_only = to_llm_input(result, include_markdown=False)
        assert "fields:" in fields_only, "Fields-only output should still include 'fields:' block"
        assert markdown not in fields_only, "Fields-only output should not contain the markdown body"
        assert len(fields_only) < len(default_text), "Fields-only output should be smaller than default"
        print(f"[PASS] Fields-only output validated ({len(fields_only)} chars)")

        # --- Markdown-only: include_fields=False ---
        markdown_only = to_llm_input(result, include_fields=False)
        assert "fields:" not in markdown_only, "Markdown-only output should not include a 'fields:' block"
        assert markdown in markdown_only, "Markdown-only output should still include the markdown body"
        print(f"[PASS] Markdown-only output validated ({len(markdown_only)} chars)")

        # --- Custom metadata ---
        with_metadata = to_llm_input(
            result,
            metadata={"source": "invoice.pdf", "department": "finance"},
        )
        assert "source: invoice.pdf" in with_metadata, "Metadata 'source' key should appear in front matter"
        assert "department: finance" in with_metadata, "Metadata 'department' key should appear in front matter"
        # Metadata is injected after contentType but before fields per helper ordering
        assert with_metadata.index("contentType: document") < with_metadata.index("source: invoice.pdf"), (
            "Custom metadata should appear after 'contentType' in front matter"
        )
        assert with_metadata.index("source: invoice.pdf") < with_metadata.index("fields:"), (
            "Custom metadata should appear before the 'fields:' block in front matter"
        )
        print("[PASS] Custom metadata injected into YAML front matter")

        await client.close()
        print("\n[SUCCESS] All test_to_llm_input_output_options_async assertions passed")

    @ContentUnderstandingPreparer()
    @recorded_by_proxy_async
    async def test_to_llm_input_multi_page_content_range_async(self, contentunderstanding_endpoint: str) -> None:
        """Section 2 of the sample — multi-page PDF with content_range.

        Validates that to_llm_input preserves original document page numbers in the
        page markers (not the renumbered offsets within the requested range).
        """
        client = self.create_async_client(endpoint=contentunderstanding_endpoint)

        multi_page_url = "https://raw.githubusercontent.com/Azure-Samples/azure-ai-content-understanding-assets/main/document/mixed_financial_invoices.pdf"

        # Analyze pages 2-3 and 5 — markers should reflect those page numbers, not 1, 2, 3
        poller = await client.begin_analyze(
            analyzer_id="prebuilt-documentSearch",
            inputs=[AnalysisInput(url=multi_page_url, content_range="2-3,5")],
        )
        result = await poller.result()

        assert result is not None and result.contents, "Analysis should return contents"
        doc = result.contents[0]
        assert isinstance(doc, DocumentContent), "Range analysis should return DocumentContent"
        page_numbers = sorted([p.page_number for p in (doc.pages or [])])
        assert page_numbers == [2, 3, 5], (
            f"content_range '2-3,5' should return pages [2, 3, 5], got {page_numbers}"
        )
        print(f"[PASS] Range analysis returned pages {page_numbers}")

        text = to_llm_input(result)
        assert text.startswith("---"), "Output should start with YAML front matter"
        assert "contentType: document" in text, "Output should declare contentType: document"
        # The 'pages' front matter key should reflect the original page numbers (2, 3, 5),
        # compressed by the helper as "2-3, 5" — not renumbered to 1-3 within the range.
        assert "pages:" in text, "Output should include a 'pages' key in front matter"
        assert "2-3, 5" in text or "'2-3, 5'" in text, (
            f"'pages' value should be '2-3, 5' (original page numbers preserved). Output:\n{text[:500]}"
        )
        print(f"[PASS] to_llm_input output validated ({len(text)} chars, pages='2-3, 5' preserved)")

        # Page markers in the markdown body should use the original page numbers
        # (<!-- page 2 -->, <!-- page 3 -->, <!-- page 5 -->), not renumbered (1, 2, 3).
        assert "<!-- page 1 -->" not in text, (
            "Page marker '<!-- page 1 -->' should not appear — we only requested pages 2-3, 5"
        )
        for expected_page in [2, 3, 5]:
            assert f"<!-- page {expected_page} -->" in text, (
                f"Page marker '<!-- page {expected_page} -->' should appear in the markdown body. "
                f"Output:\n{text[:800]}"
            )
        print("[PASS] Page markers verified: <!-- page 2 -->, <!-- page 3 -->, <!-- page 5 -->")

        await client.close()
        print("\n[SUCCESS] All test_to_llm_input_multi_page_content_range_async assertions passed")

    @ContentUnderstandingPreparer()
    @recorded_by_proxy_async
    async def test_to_llm_input_multi_segment_video_async(self, contentunderstanding_endpoint: str) -> None:
        """Section 3 of the sample — multi-segment video.

        Validates that to_llm_input renders each segment with its time range in the
        front matter and separates segments with '*****' dividers.
        """
        client = self.create_async_client(endpoint=contentunderstanding_endpoint)

        video_url = "https://raw.githubusercontent.com/Azure-Samples/azure-ai-content-understanding-assets/main/videos/sdk_samples/FlightSimulator.mp4"

        poller = await client.begin_analyze(
            analyzer_id="prebuilt-videoSearch",
            inputs=[AnalysisInput(url=video_url)],
        )
        result = await poller.result()

        assert result is not None and result.contents, "Video analysis should return contents"
        assert all(isinstance(c, AudioVisualContent) for c in result.contents), (
            "Video analysis should return AudioVisualContent items"
        )
        segment_count = len(result.contents)
        print(f"[PASS] Video analyzed: {segment_count} segment(s)")

        text = to_llm_input(result)
        assert text.startswith("---"), "Output should start with YAML front matter"
        assert "contentType: audioVisual" in text, "Output should declare contentType: audioVisual"

        if segment_count > 1:
            # Multi-segment: each segment has its own front matter with timeRange
            # and is separated by '*****' divider (n segments => n-1 dividers).
            expected_dividers = segment_count - 1
            assert text.count("*****") == expected_dividers, (
                f"{segment_count} segments should produce {expected_dividers} '*****' dividers, "
                f"got {text.count('*****')}"
            )
            assert text.count("timeRange:") == segment_count, (
                f"Each of {segment_count} segments should declare a 'timeRange', "
                f"got {text.count('timeRange:')}"
            )
            print(f"[PASS] Multi-segment output: {segment_count} timeRange entries, "
                  f"{expected_dividers} '*****' dividers")
        else:
            # Single segment: no dividers, single timeRange (or no timeRange if absent)
            assert "*****" not in text, "Single-segment output should not contain '*****' divider"
            print("[PASS] Single-segment video output validated")

        print(f"[PASS] to_llm_input output validated ({len(text)} chars)")
        await client.close()
        print("\n[SUCCESS] All test_to_llm_input_multi_segment_video_async assertions passed")

    @ContentUnderstandingPreparer()
    @recorded_by_proxy_async
    async def test_to_llm_input_audio_with_content_range_async(self, contentunderstanding_endpoint: str) -> None:
        """Section 4 of the sample — audio with content_range and custom metadata.

        Validates that to_llm_input handles audio analysis with a content_range
        (first 10 seconds) and that custom metadata is injected into the front matter.
        """
        client = self.create_async_client(endpoint=contentunderstanding_endpoint)

        audio_url = "https://raw.githubusercontent.com/Azure-Samples/azure-ai-content-understanding-assets/main/audio/callCenterRecording.mp3"

        # content_range for audio is in milliseconds: '0-10000' = first 10 seconds
        poller = await client.begin_analyze(
            analyzer_id="prebuilt-audioSearch",
            inputs=[AnalysisInput(url=audio_url, content_range="0-10000")],
        )
        result = await poller.result()

        assert result is not None and result.contents, "Audio analysis should return contents"
        assert all(isinstance(c, AudioVisualContent) for c in result.contents), (
            "Audio analysis should return AudioVisualContent items"
        )
        print(f"[PASS] Audio analyzed: {len(result.contents)} segment(s)")

        # Include metadata to track the source file in RAG pipelines
        text = to_llm_input(
            result,
            metadata={"source": "callCenterRecording.mp3"},
        )
        assert text.startswith("---"), "Output should start with YAML front matter"
        assert "contentType: audioVisual" in text, "Output should declare contentType: audioVisual"
        assert "source: callCenterRecording.mp3" in text, (
            "Custom metadata 'source' key should appear in front matter"
        )
        # Metadata should appear after contentType per helper ordering
        assert text.index("contentType: audioVisual") < text.index("source: callCenterRecording.mp3"), (
            "Custom metadata should appear after 'contentType' in front matter"
        )
        print(f"[PASS] to_llm_input output validated ({len(text)} chars, includes source metadata)")

        await client.close()
        print("\n[SUCCESS] All test_to_llm_input_audio_with_content_range_async assertions passed")



# pylint: disable=line-too-long,useless-suppression
# ------------------------------------
# Copyright (c) Microsoft Corporation.
# Licensed under the MIT License.
# ------------------------------------

"""
DESCRIPTION:
    Generates supervised fine-tuning data from a Markdown reference document
    uploaded as an Azure OpenAI File. The sample:

      1. Uploads a short reference document via the Azure OpenAI Files API
         (`purpose=user_data`) so it can be referenced by file id.
      2. Creates a `DataGenerationJob` (scenario=SUPERVISED_FINETUNING,
         type=simple_qna) that synthesizes short-answer and long-answer
         question / answer pairs from the file content and emits them as
         training and validation JSONL files.
      3. Polls the job to completion and prints every generated file output.
      4. Cleans up the generated fine-tuning files, the Azure OpenAI input file, and the data generation job.

    `simple_qna` REQUIRES `model_options` — the service uses the configured LLM
    to synthesize the QnA pairs. Setting `train_split` triggers a split of
    the generated samples into two Azure OpenAI output files.

USAGE:
    python sample_dataset_generation_job_simpleqna_for_finetuning.py

    Before running the sample:

    pip install "azure-ai-projects>=2.2.0" azure-identity openai python-dotenv

    Set these environment variables with your own values:
    1) FOUNDRY_PROJECT_ENDPOINT - Required. The Azure AI Project endpoint, as found
       in the overview page of your Microsoft Foundry project.
    2) FOUNDRY_MODEL_NAME - Required. The name of an Azure OpenAI model
       deployment used to synthesize the QnA samples. For `simple_qna` fine-tuning,
       the deployment must support the chat completions API (e.g. `gpt-4o`, `gpt-4.1`).
    3) DATASET_NAME - Optional. Name to assign to the generated output files
       (used as the file name prefix). Defaults to `simpleqna-finetuning-sample`.
       The service caps the rendered output name at 50 characters, so keep
       custom values short — the sample appends a unique run id suffix.
    4) POLL_INTERVAL_SECONDS - Optional. Number of seconds to sleep between status
       polls for the data generation job. Defaults to 10.
"""

import io
import os
import time
import uuid
from datetime import datetime, timezone

from dotenv import load_dotenv

from azure.identity import DefaultAzureCredential
from azure.ai.projects import AIProjectClient
from azure.ai.projects.models import (
    DataGenerationJob,
    DataGenerationJobInputs,
    DataGenerationJobOutputOptions,
    DataGenerationJobScenario,
    DataGenerationModelOptions,
    FileDataGenerationJobOutput,
    FileDataGenerationJobSource,
    JobStatus,
    SimpleQnADataGenerationJobOptions,
    SimpleQnAFineTuningQuestionType,
)

load_dotenv()

endpoint = os.environ["FOUNDRY_PROJECT_ENDPOINT"]
model_name = os.environ["FOUNDRY_MODEL_NAME"]
dataset_name = os.environ.get("DATASET_NAME", "simpleqna-finetuning-sample")
poll_interval_seconds = int(os.environ.get("POLL_INTERVAL_SECONDS", "10"))

# Unique per-run output name so repeated runs do not collide.
# Output names are capped at 50 characters by the service.
run_id = f"{datetime.now(tz=timezone.utc).strftime('%y%m%d%H%M%S')}-{uuid.uuid4().hex[:4]}"
output_name = f"{dataset_name}-{run_id}"
if len(output_name) > 50:
    raise ValueError(
        f"Output name `{output_name}` exceeds the 50-character service limit. "
        f"Lower DATASET_NAME (currently `{dataset_name}`) so that `<DATASET_NAME>-<run id>` fits within 50 characters."
    )

# Reference document the sample uploads as an Azure OpenAI file. The service
# requires the file to contain at least 1 KB of content to generate QnA from.
SEED_REFERENCE_DOCUMENT = """# Widgets and Gizmos Reference

## Products
- Widget: blue, manufactured at Factory 7 in Acme, carbon-fiber, rated to 80 C, sold in packs of 4, 250 g each.
- Gizmo: red, manufactured at Factory 12 in Bedrock, carbon-fiber, rated to 80 C, sold individually, 1.2 kg each.
- Sprocket: green, manufactured at Factory 3 in Acme, stainless steel, rated to 200 C, sold individually, 500 g each.

## Operations
- Factory operates weekdays 0700-1900 local time.
- Closed on public holidays, except for the annual maintenance run on December 27.
- ISO 9001 certified; audited annually by an independent third party.
- Quality control samples every 100th unit and runs full destructive testing on every 5000th unit.

## Customer support
- Warranty claims: email support@example.com with the serial number printed on the underside of the product.
- Returns: accepted within 30 days if unopened; opened items are eligible for repair only.
- Bulk orders (50+ units): contact sales@example.com for volume pricing and an extended 90-day return window.
- Replacement parts: orderable directly from the support portal using the original order number.

## Pricing and SLAs
- Widget pack: USD 24.99 per 4-pack; free shipping on orders over USD 75.
- Gizmo unit: USD 49.99; free shipping on orders over USD 75.
- Sprocket unit: USD 14.99; ships from regional warehouses in 1-2 business days.
- Standard support response: within one business day. Priority support response: within four hours.
"""

TERMINAL_STATUSES = {JobStatus.SUCCEEDED, JobStatus.FAILED, JobStatus.CANCELLED}

with (
    DefaultAzureCredential() as credential,
    AIProjectClient(endpoint=endpoint, credential=credential) as project_client,
    project_client.get_openai_client() as openai_client,
):

    # ------------------------------------------------------------------
    # 1. Upload the seed reference document as an Azure OpenAI file.
    # ------------------------------------------------------------------
    seed_filename = f"widgets-gizmos-seed-{run_id}.md"
    print(f"Upload the seed reference document as Azure OpenAI file `{seed_filename}`.")
    seed_file = openai_client.files.create(
        file=(seed_filename, io.BytesIO(SEED_REFERENCE_DOCUMENT.encode("utf-8"))),
        purpose="user_data",
    )
    print(f"Uploaded Azure OpenAI file (id: {seed_file.id}).")

    # Wait for the file to finish processing — the data generation service
    # rejects references to files that are not yet in the `processed` state.
    print("Wait for the Azure OpenAI file to be processed.", end="", flush=True)
    while seed_file.status not in ("processed", "error"):
        time.sleep(2)
        seed_file = openai_client.files.retrieve(file_id=seed_file.id)
        print(".", end="", flush=True)
    print()
    if seed_file.status != "processed":
        raise RuntimeError(f"Azure OpenAI file `{seed_file.id}` failed to process: status=`{seed_file.status}`.")

    # ------------------------------------------------------------------
    # 2. Submit a fine-tuning data generation job that consumes the file.
    # ------------------------------------------------------------------
    print("Create a fine-tuning data generation job from the Azure OpenAI file.")
    job = DataGenerationJob(
        inputs=DataGenerationJobInputs(
            name=f"simpleqna-finetuning-{run_id}",
            scenario=DataGenerationJobScenario.SUPERVISED_FINETUNING,
            sources=[
                FileDataGenerationJobSource(
                    description="Widgets & Gizmos product / operations reference (Azure OpenAI file).",
                    id=seed_file.id,
                ),
            ],
            options=SimpleQnADataGenerationJobOptions(
                # Service requires max_samples to be between 15 and 1000.
                max_samples=15,
                # `simple_qna` REQUIRES model_options.
                model_options=DataGenerationModelOptions(model=model_name),
                # Split generated samples 80% training / 20% validation.
                train_split=0.8,
                # Ask for both short-answer and long-answer questions.
                question_types=[
                    SimpleQnAFineTuningQuestionType.SHORT_ANSWER,
                    SimpleQnAFineTuningQuestionType.LONG_ANSWER,
                ],
            ),
            output_options=DataGenerationJobOutputOptions(name=output_name),
        ),
    )
    job = project_client.beta.datasets.create_generation_job(job=job)
    print(f"Created data generation job `{job.id}` (status: `{job.status}`).")

    print(f"Poll job `{job.id}` until it reaches a terminal state.", end="", flush=True)
    while True:
        job = project_client.beta.datasets.get_generation_job(job_id=job.id)
        if job.status in TERMINAL_STATUSES:
            break
        time.sleep(poll_interval_seconds)
        print(".", end="", flush=True)
    print()
    print(f"Final job status: `{job.status}`.")

    if job.status != JobStatus.SUCCEEDED:
        message = job.error.message if job.error is not None else "<no error message>"
        raise RuntimeError(f"Job `{job.id}` ended with status `{job.status}`: {message}")

    # ------------------------------------------------------------------
    # 3. Inspect the generated fine-tuning file outputs.
    # ------------------------------------------------------------------
    # `train_split=0.8` produces two Azure OpenAI files: a training partition
    # and a validation partition. Both are emitted as FileDataGenerationJobOutput
    # entries in `job.result.outputs`.
    file_outputs = [
        output
        for output in ((job.result.outputs if job.result is not None else None) or [])
        if isinstance(output, FileDataGenerationJobOutput)
    ]
    if not file_outputs:
        raise RuntimeError(f"Job `{job.id}` did not produce any file outputs.")

    print(f"Generated {len(file_outputs)} fine-tuning file(s):")
    for output in file_outputs:
        if not output.id:
            raise RuntimeError(f"Job `{job.id}` returned a file output without an id.")
        # Resolve the Azure OpenAI file to surface its real filename and size.
        file_info = openai_client.files.retrieve(file_id=output.id)
        print(f"  - filename=`{file_info.filename}` id=`{output.id}` bytes={file_info.bytes}")
    if job.result is not None and job.result.generated_samples is not None:
        print(f"Generated samples: {job.result.generated_samples}")

    # ------------------------------------------------------------------
    # 4. Clean up.
    # ------------------------------------------------------------------
    for output in file_outputs:
        print(f"Delete the generated Azure OpenAI file `{output.id}`.")
        openai_client.files.delete(file_id=output.id)

    print(f"Delete the Azure OpenAI input file `{seed_file.id}`.")
    openai_client.files.delete(file_id=seed_file.id)

    print(f"Delete the data generation job `{job.id}`.")
    project_client.beta.datasets.delete_generation_job(job_id=job.id)



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from azure.identity import DefaultAzureCredential

from azure.mgmt.dataprotection import DataProtectionMgmtClient

"""
# PREREQUISITES
    pip install azure-identity
    pip install azure-mgmt-dataprotection
# USAGE
    python create_or_update_backup_policy.py

    Before run the sample, please set the values of the client ID, tenant ID and client secret
    of the AAD application as environment variables: AZURE_CLIENT_ID, AZURE_TENANT_ID,
    AZURE_CLIENT_SECRET. For more info about how to get the value, please see:
    https://docs.microsoft.com/azure/active-directory/develop/howto-create-service-principal-portal
"""


def main():
    client = DataProtectionMgmtClient(
        credential=DefaultAzureCredential(),
        subscription_id="SUBSCRIPTION_ID",
    )

    response = client.backup_policies.create_or_update(
        resource_group_name="000pikumar",
        vault_name="PrivatePreviewVault",
        backup_policy_name="OSSDBPolicy",
        parameters={
            "properties": {
                "datasourceTypes": ["OssDB"],
                "objectType": "BackupPolicy",
                "policyRules": [
                    {
                        "backupParameters": {"backupType": "Full", "objectType": "AzureBackupParams"},
                        "dataStore": {"dataStoreType": "VaultStore", "objectType": "DataStoreInfoBase"},
                        "name": "BackupWeekly",
                        "objectType": "AzureBackupRule",
                        "trigger": {
                            "objectType": "ScheduleBasedTriggerContext",
                            "schedule": {"repeatingTimeIntervals": ["R/2019-11-20T08:00:00-08:00/P1W"]},
                            "taggingCriteria": [
                                {"isDefault": True, "tagInfo": {"tagName": "Default"}, "taggingPriority": 99},
                                {
                                    "criteria": [
                                        {
                                            "daysOfTheWeek": ["Sunday"],
                                            "objectType": "ScheduleBasedBackupCriteria",
                                            "scheduleTimes": ["2019-03-01T13:00:00Z"],
                                        }
                                    ],
                                    "isDefault": False,
                                    "tagInfo": {"tagName": "Weekly"},
                                    "taggingPriority": 20,
                                },
                            ],
                        },
                    },
                    {
                        "isDefault": True,
                        "lifecycles": [
                            {
                                "deleteAfter": {"duration": "P1W", "objectType": "AbsoluteDeleteOption"},
                                "sourceDataStore": {"dataStoreType": "VaultStore", "objectType": "DataStoreInfoBase"},
                            }
                        ],
                        "name": "Default",
                        "objectType": "AzureRetentionRule",
                    },
                    {
                        "isDefault": False,
                        "lifecycles": [
                            {
                                "deleteAfter": {"duration": "P12W", "objectType": "AbsoluteDeleteOption"},
                                "sourceDataStore": {"dataStoreType": "VaultStore", "objectType": "DataStoreInfoBase"},
                            }
                        ],
                        "name": "Weekly",
                        "objectType": "AzureRetentionRule",
                    },
                ],
            }
        },
    )
    print(response)


# x-ms-original-file: 2026-03-01/PolicyCRUD/CreateOrUpdateBackupPolicy.json
if __name__ == "__main__":
    main()



# pylint: disable=line-too-long,useless-suppression,too-many-lines
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=useless-super-delegation

import datetime
from typing import Any, Mapping, Optional, TYPE_CHECKING, Union, overload

from .._utils.model_base import Model as _Model, rest_field

if TYPE_CHECKING:
    from .. import models as _models


class AgriServiceConfig(_Model):
    """Config of the AgriService resource instance.

    :ivar instance_uri: Instance URI of the AgriService instance.
    :vartype instance_uri: str
    :ivar version: Version of AgriService instance.
    :vartype version: str
    :ivar app_service_resource_id: App service resource Id.
    :vartype app_service_resource_id: str
    :ivar cosmos_db_resource_id: Cosmos Db resource Id.
    :vartype cosmos_db_resource_id: str
    :ivar storage_account_resource_id: Storage account resource Id.
    :vartype storage_account_resource_id: str
    :ivar key_vault_resource_id: Key vault resource Id.
    :vartype key_vault_resource_id: str
    :ivar redis_cache_resource_id: Redis cache resource Id.
    :vartype redis_cache_resource_id: str
    """

    instance_uri: Optional[str] = rest_field(name="instanceUri", visibility=["read"])
    """Instance URI of the AgriService instance."""
    version: Optional[str] = rest_field(visibility=["read"])
    """Version of AgriService instance."""
    app_service_resource_id: Optional[str] = rest_field(name="appServiceResourceId", visibility=["read"])
    """App service resource Id."""
    cosmos_db_resource_id: Optional[str] = rest_field(name="cosmosDbResourceId", visibility=["read"])
    """Cosmos Db resource Id."""
    storage_account_resource_id: Optional[str] = rest_field(name="storageAccountResourceId", visibility=["read"])
    """Storage account resource Id."""
    key_vault_resource_id: Optional[str] = rest_field(name="keyVaultResourceId", visibility=["read"])
    """Key vault resource Id."""
    redis_cache_resource_id: Optional[str] = rest_field(name="redisCacheResourceId", visibility=["read"])
    """Redis cache resource Id."""


class Resource(_Model):
    """Resource.

    :ivar id: Fully qualified resource ID for the resource. Ex -
     /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or
     "Microsoft.Storage/storageAccounts".
    :vartype type: str
    :ivar system_data: Azure Resource Manager metadata containing createdBy and modifiedBy
     information.
    :vartype system_data: ~azure.mgmt.agricultureplatform.models.SystemData
    """

    id: Optional[str] = rest_field(visibility=["read"])
    """Fully qualified resource ID for the resource. Ex -
     /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}."""
    name: Optional[str] = rest_field(visibility=["read"])
    """The name of the resource."""
    type: Optional[str] = rest_field(visibility=["read"])
    """The type of the resource. E.g. \"Microsoft.Compute/virtualMachines\" or
     \"Microsoft.Storage/storageAccounts\"."""
    system_data: Optional["_models.SystemData"] = rest_field(name="systemData", visibility=["read"])
    """Azure Resource Manager metadata containing createdBy and modifiedBy information."""


class TrackedResource(Resource):
    """Tracked Resource.

    :ivar id: Fully qualified resource ID for the resource. Ex -
     /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or
     "Microsoft.Storage/storageAccounts".
    :vartype type: str
    :ivar system_data: Azure Resource Manager metadata containing createdBy and modifiedBy
     information.
    :vartype system_data: ~azure.mgmt.agricultureplatform.models.SystemData
    :ivar tags: Resource tags.
    :vartype tags: dict[str, str]
    :ivar location: The geo-location where the resource lives. Required.
    :vartype location: str
    """

    tags: Optional[dict[str, str]] = rest_field(visibility=["read", "create", "update", "delete", "query"])
    """Resource tags."""
    location: str = rest_field(visibility=["read", "create"])
    """The geo-location where the resource lives. Required."""

    @overload
    def __init__(
        self,
        *,
        location: str,
        tags: Optional[dict[str, str]] = None,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class AgriServiceResource(TrackedResource):
    """Schema of the AgriService resource from Microsoft.AgriculturePlatform resource provider.

    :ivar id: Fully qualified resource ID for the resource. Ex -
     /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}.
    :vartype id: str
    :ivar name: The name of the resource.
    :vartype name: str
    :ivar type: The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or
     "Microsoft.Storage/storageAccounts".
    :vartype type: str
    :ivar system_data: Azure Resource Manager metadata containing createdBy and modifiedBy
     information.
    :vartype system_data: ~azure.mgmt.agricultureplatform.models.SystemData
    :ivar tags: Resource tags.
    :vartype tags: dict[str, str]
    :ivar location: The geo-location where the resource lives. Required.
    :vartype location: str
    :ivar properties: The resource-specific properties for this resource.
    :vartype properties: ~azure.mgmt.agricultureplatform.models.AgriServiceResourceProperties
    :ivar identity: The managed service identities assigned to this resource.
    :vartype identity: ~azure.mgmt.agricultureplatform.models.ManagedServiceIdentity
    :ivar sku: The SKU (Stock Keeping Unit) assigned to this resource.
    :vartype sku: ~azure.mgmt.agricultureplatform.models.Sku
    """

    properties: Optional["_models.AgriServiceResourceProperties"] = rest_field(
        visibility=["read", "create", "update", "delete", "query"]
    )
    """The resource-specific properties for this resource."""
    identity: Optional["_models.ManagedServiceIdentity"] = rest_field(
        visibility=["read", "create", "update", "delete", "query"]
    )
    """The managed service identities assigned to this resource."""
    sku: Optional["_models.Sku"] = rest_field(visibility=["read", "create", "update", "delete", "query"])
    """The SKU (Stock Keeping Unit) assigned to this resource."""

    @overload
    def __init__(
        self,
        *,
        location: str,
        tags: Optional[dict[str, str]] = None,
        properties: Optional["_models.AgriServiceResourceProperties"] = None,
        identity: Optional["_models.ManagedServiceIdentity"] = None,
        sku: Optional["_models.Sku"] = None,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class AgriServiceResourceProperties(_Model):
    """Details of the Agriculture AgriDataManager.

    :ivar provisioning_state: The status of the last operation. Known values are: "Succeeded",
     "Failed", "Canceled", "Provisioning", "Updating", "Deleting", and "Accepted".
    :vartype provisioning_state: str or ~azure.mgmt.agricultureplatform.models.ProvisioningState
    :ivar config: Config of the AgriService instance.
    :vartype config: ~azure.mgmt.agricultureplatform.models.AgriServiceConfig
    :ivar managed_on_behalf_of_configuration: Managed On Behalf Of Configuration.
    :vartype managed_on_behalf_of_configuration:
     ~azure.mgmt.agricultureplatform.models.ManagedOnBehalfOfConfiguration
    :ivar data_connector_credentials: Data connector credentials of AgriService instance.
    :vartype data_connector_credentials:
     list[~azure.mgmt.agricultureplatform.models.DataConnectorCredentialMap]
    :ivar installed_solutions: AgriService installed solutions.
    :vartype installed_solutions: list[~azure.mgmt.agricultureplatform.models.InstalledSolutionMap]
    """

    provisioning_state: Optional[Union[str, "_models.ProvisioningState"]] = rest_field(
        name="provisioningState", visibility=["read"]
    )
    """The status of the last operation. Known values are: \"Succeeded\", \"Failed\", \"Canceled\",
     \"Provisioning\", \"Updating\", \"Deleting\", and \"Accepted\"."""
    config: Optional["_models.AgriServiceConfig"] = rest_field(visibility=["read", "create", "update"])
    """Config of the AgriService instance."""
    managed_on_behalf_of_configuration: Optional["_models.ManagedOnBehalfOfConfiguration"] = rest_field(
        name="managedOnBehalfOfConfiguration", visibility=["read"]
    )
    """Managed On Behalf Of Configuration."""
    data_connector_credentials: Optional[list["_models.DataConnectorCredentialMap"]] = rest_field(
        name="dataConnectorCredentials", visibility=["read", "create", "update"]
    )
    """Data connector credentials of AgriService instance."""
    installed_solutions: Optional[list["_models.InstalledSolutionMap"]] = rest_field(
        name="installedSolutions", visibility=["read", "create", "update"]
    )
    """AgriService installed solutions."""

    @overload
    def __init__(
        self,
        *,
        config: Optional["_models.AgriServiceConfig"] = None,
        data_connector_credentials: Optional[list["_models.DataConnectorCredentialMap"]] = None,
        installed_solutions: Optional[list["_models.InstalledSolutionMap"]] = None,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class AgriServiceResourceUpdate(_Model):
    """The type used for update operations of the AgriServiceResource.

    :ivar identity: The managed service identities assigned to this resource.
    :vartype identity: ~azure.mgmt.agricultureplatform.models.ManagedServiceIdentity
    :ivar sku: The SKU (Stock Keeping Unit) assigned to this resource.
    :vartype sku: ~azure.mgmt.agricultureplatform.models.Sku
    :ivar tags: Resource tags.
    :vartype tags: dict[str, str]
    :ivar properties: The resource-specific properties for this resource.
    :vartype properties: ~azure.mgmt.agricultureplatform.models.AgriServiceResourceUpdateProperties
    """

    identity: Optional["_models.ManagedServiceIdentity"] = rest_field(
        visibility=["read", "create", "update", "delete", "query"]
    )
    """The managed service identities assigned to this resource."""
    sku: Optional["_models.Sku"] = rest_field(visibility=["read", "create", "update", "delete", "query"])
    """The SKU (Stock Keeping Unit) assigned to this resource."""
    tags: Optional[dict[str, str]] = rest_field(visibility=["read", "create", "update", "delete", "query"])
    """Resource tags."""
    properties: Optional["_models.AgriServiceResourceUpdateProperties"] = rest_field(
        visibility=["read", "create", "update", "delete", "query"]
    )
    """The resource-specific properties for this resource."""

    @overload
    def __init__(
        self,
        *,
        identity: Optional["_models.ManagedServiceIdentity"] = None,
        sku: Optional["_models.Sku"] = None,
        tags: Optional[dict[str, str]] = None,
        properties: Optional["_models.AgriServiceResourceUpdateProperties"] = None,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class AgriServiceResourceUpdateProperties(_Model):
    """The updatable properties of the AgriServiceResource.

    :ivar config: Config of the AgriService instance.
    :vartype config: ~azure.mgmt.agricultureplatform.models.AgriServiceConfig
    :ivar data_connector_credentials: Data connector credentials of AgriService instance.
    :vartype data_connector_credentials:
     list[~azure.mgmt.agricultureplatform.models.DataConnectorCredentialMap]
    :ivar installed_solutions: AgriService installed solutions.
    :vartype installed_solutions: list[~azure.mgmt.agricultureplatform.models.InstalledSolutionMap]
    """

    config: Optional["_models.AgriServiceConfig"] = rest_field(visibility=["read", "create", "update"])
    """Config of the AgriService instance."""
    data_connector_credentials: Optional[list["_models.DataConnectorCredentialMap"]] = rest_field(
        name="dataConnectorCredentials", visibility=["read", "create", "update"]
    )
    """Data connector credentials of AgriService instance."""
    installed_solutions: Optional[list["_models.InstalledSolutionMap"]] = rest_field(
        name="installedSolutions", visibility=["read", "create", "update"]
    )
    """AgriService installed solutions."""

    @overload
    def __init__(
        self,
        *,
        config: Optional["_models.AgriServiceConfig"] = None,
        data_connector_credentials: Optional[list["_models.DataConnectorCredentialMap"]] = None,
        installed_solutions: Optional[list["_models.InstalledSolutionMap"]] = None,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class AvailableAgriSolutionListResult(_Model):
    """The list of available agri solutions.

    :ivar solutions: Agri solutions list. Required.
    :vartype solutions:
     list[~azure.mgmt.agricultureplatform.models.DataManagerForAgricultureSolution]
    """

    solutions: list["_models.DataManagerForAgricultureSolution"] = rest_field(
        visibility=["read", "create", "update", "delete", "query"]
    )
    """Agri solutions list. Required."""

    @overload
    def __init__(
        self,
        *,
        solutions: list["_models.DataManagerForAgricultureSolution"],
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class DataConnectorCredentialMap(_Model):
    """Mapping of data connector credentials.

    :ivar key: The key representing the credential. Required.
    :vartype key: str
    :ivar value: The data connector credential value. Required.
    :vartype value: ~azure.mgmt.agricultureplatform.models.DataConnectorCredentials
    """

    key: str = rest_field(visibility=["read", "create", "update", "delete", "query"])
    """The key representing the credential. Required."""
    value: "_models.DataConnectorCredentials" = rest_field(visibility=["read", "create", "update", "delete", "query"])
    """The data connector credential value. Required."""

    @overload
    def __init__(
        self,
        *,
        key: str,
        value: "_models.DataConnectorCredentials",
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class DataConnectorCredentials(_Model):
    """The properties related to an AgriService data connector.

    :ivar kind: Type of credential. Known values are: "OAuthClientCredentials" and
     "ApiKeyAuthCredentials".
    :vartype kind: str or ~azure.mgmt.agricultureplatform.models.AuthCredentialsKind
    :ivar client_id: Client Id associated with the provider, if type of credentials is
     OAuthClientCredentials.
    :vartype client_id: str
    :ivar key_vault_uri: Uri of the key vault.
    :vartype key_vault_uri: str
    :ivar key_name: Name of the key vault key.
    :vartype key_name: str
    :ivar key_version: Version of the key vault key.
    :vartype key_version: str
    """

    kind: Optional[Union[str, "_models.AuthCredentialsKind"]] = rest_field(visibility=["read", "create", "update"])
    """Type of credential. Known values are: \"OAuthClientCredentials\" and \"ApiKeyAuthCredentials\"."""
    client_id: Optional[str] = rest_field(name="clientId", visibility=["read", "create", "update"])
    """Client Id associated with the provider, if type of credentials is OAuthClientCredentials."""
    key_vault_uri: Optional[str] = rest_field(name="keyVaultUri", visibility=["read", "create", "update"])
    """Uri of the key vault."""
    key_name: Optional[str] = rest_field(name="keyName", visibility=["read", "create", "update"])
    """Name of the key vault key."""
    key_version: Optional[str] = rest_field(name="keyVersion", visibility=["read", "create", "update"])
    """Version of the key vault key."""

    @overload
    def __init__(
        self,
        *,
        kind: Optional[Union[str, "_models.AuthCredentialsKind"]] = None,
        client_id: Optional[str] = None,
        key_vault_uri: Optional[str] = None,
        key_name: Optional[str] = None,
        key_version: Optional[str] = None,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class DataManagerForAgricultureSolution(_Model):
    """Data Manager for Agriculture solution.

    :ivar partner_id: Partner Id. Required.
    :vartype partner_id: str
    :ivar solution_id: Solution Id. Required.
    :vartype solution_id: str
    :ivar partner_tenant_id: Partner tenant Id. Required.
    :vartype partner_tenant_id: str
    :ivar data_access_scopes: Data access scopes. Required.
    :vartype data_access_scopes: list[str]
    :ivar market_place_offer_details: Marketplace offer details. Required.
    :vartype market_place_offer_details:
     ~azure.mgmt.agricultureplatform.models.MarketPlaceOfferDetails
    :ivar saas_application_id: Saas application Id. Required.
    :vartype saas_application_id: str
    :ivar access_azure_data_manager_for_agriculture_application_id: Entra application Id used to
     access azure data manager for agriculture instance. Required.
    :vartype access_azure_data_manager_for_agriculture_application_id: str
    :ivar access_azure_data_manager_for_agriculture_application_name: Entra application name used
     to access azure data manager for agriculture instance. Required.
    :vartype access_azure_data_manager_for_agriculture_application_name: str
    :ivar is_validate_input: Whether solution inference will validate input. Required.
    :vartype is_validate_input: bool
    """

    partner_id: str = rest_field(name="partnerId", visibility=["read", "create", "update", "delete", "query"])
    """Partner Id. Required."""
    solution_id: str = rest_field(name="solutionId", visibility=["read", "create", "update", "delete", "query"])
    """Solution Id. Required."""
    partner_tenant_id: str = rest_field(
        name="partnerTenantId", visibility=["read", "create", "update", "delete", "query"]
    )
    """Partner tenant Id. Required."""
    data_access_scopes: list[str] = rest_field(
        name="dataAccessScopes", visibility=["read", "create", "update", "delete", "query"]
    )
    """Data access scopes. Required."""
    market_place_offer_details: "_models.MarketPlaceOfferDetails" = rest_field(
        name="marketPlaceOfferDetails", visibility=["read", "create", "update", "delete", "query"]
    )
    """Marketplace offer details. Required."""
    saas_application_id: str = rest_field(
        name="saasApplicationId", visibility=["read", "create", "update", "delete", "query"]
    )
    """Saas application Id. Required."""
    access_azure_data_manager_for_agriculture_application_id: str = rest_field(
        name="accessAzureDataManagerForAgricultureApplicationId",
        visibility=["read", "create", "update", "delete", "query"],
    )
    """Entra application Id used to access azure data manager for agriculture instance. Required."""
    access_azure_data_manager_for_agriculture_application_name: str = rest_field(
        name="accessAzureDataManagerForAgricultureApplicationName",
        visibility=["read", "create", "update", "delete", "query"],
    )
    """Entra application name used to access azure data manager for agriculture instance. Required."""
    is_validate_input: bool = rest_field(
        name="isValidateInput", visibility=["read", "create", "update", "delete", "query"]
    )
    """Whether solution inference will validate input. Required."""

    @overload
    def __init__(
        self,
        *,
        partner_id: str,
        solution_id: str,
        partner_tenant_id: str,
        data_access_scopes: list[str],
        market_place_offer_details: "_models.MarketPlaceOfferDetails",
        saas_application_id: str,
        access_azure_data_manager_for_agriculture_application_id: str,
        access_azure_data_manager_for_agriculture_application_name: str,
        is_validate_input: bool,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class ErrorAdditionalInfo(_Model):
    """The resource management error additional info.

    :ivar type: The additional info type.
    :vartype type: str
    :ivar info: The additional info.
    :vartype info: any
    """

    type: Optional[str] = rest_field(visibility=["read"])
    """The additional info type."""
    info: Optional[Any] = rest_field(visibility=["read"])
    """The additional info."""


class ErrorDetail(_Model):
    """The error detail.

    :ivar code: The error code.
    :vartype code: str
    :ivar message: The error message.
    :vartype message: str
    :ivar target: The error target.
    :vartype target: str
    :ivar details: The error details.
    :vartype details: list[~azure.mgmt.agricultureplatform.models.ErrorDetail]
    :ivar additional_info: The error additional info.
    :vartype additional_info: list[~azure.mgmt.agricultureplatform.models.ErrorAdditionalInfo]
    """

    code: Optional[str] = rest_field(visibility=["read"])
    """The error code."""
    message: Optional[str] = rest_field(visibility=["read"])
    """The error message."""
    target: Optional[str] = rest_field(visibility=["read"])
    """The error target."""
    details: Optional[list["_models.ErrorDetail"]] = rest_field(visibility=["read"])
    """The error details."""
    additional_info: Optional[list["_models.ErrorAdditionalInfo"]] = rest_field(
        name="additionalInfo", visibility=["read"]
    )
    """The error additional info."""


class ErrorResponse(_Model):
    """Error response.

    :ivar error: The error object.
    :vartype error: ~azure.mgmt.agricultureplatform.models.ErrorDetail
    """

    error: Optional["_models.ErrorDetail"] = rest_field(visibility=["read", "create", "update", "delete", "query"])
    """The error object."""

    @overload
    def __init__(
        self,
        *,
        error: Optional["_models.ErrorDetail"] = None,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class InstalledSolutionMap(_Model):
    """Mapping of installed solutions.

    :ivar key: The key representing the installed solution. Required.
    :vartype key: str
    :ivar value: The installed solution value. Required.
    :vartype value: ~azure.mgmt.agricultureplatform.models.Solution
    """

    key: str = rest_field(visibility=["read", "create", "update", "delete", "query"])
    """The key representing the installed solution. Required."""
    value: "_models.Solution" = rest_field(visibility=["read", "create", "update", "delete", "query"])
    """The installed solution value. Required."""

    @overload
    def __init__(
        self,
        *,
        key: str,
        value: "_models.Solution",
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class ManagedOnBehalfOfConfiguration(_Model):
    """Configuration of the managed on behalf of resource.

    :ivar mobo_broker_resources: Associated MoboBrokerResources. Required.
    :vartype mobo_broker_resources: list[~azure.mgmt.agricultureplatform.models.MoboBrokerResource]
    """

    mobo_broker_resources: list["_models.MoboBrokerResource"] = rest_field(
        name="moboBrokerResources", visibility=["read"]
    )
    """Associated MoboBrokerResources. Required."""


class ManagedServiceIdentity(_Model):
    """Managed service identity (system assigned and/or user assigned identities).

    :ivar principal_id: The service principal ID of the system assigned identity. This property
     will only be provided for a system assigned identity.
    :vartype principal_id: str
    :ivar tenant_id: The tenant ID of the system assigned identity. This property will only be
     provided for a system assigned identity.
    :vartype tenant_id: str
    :ivar type: The type of managed identity assigned to this resource. Required. Known values are:
     "None", "SystemAssigned", "UserAssigned", and "SystemAssigned,UserAssigned".
    :vartype type: str or ~azure.mgmt.agricultureplatform.models.ManagedServiceIdentityType
    :ivar user_assigned_identities: The identities assigned to this resource by the user.
    :vartype user_assigned_identities: dict[str,
     ~azure.mgmt.agricultureplatform.models.UserAssignedIdentity]
    """

    principal_id: Optional[str] = rest_field(name="principalId", visibility=["read"])
    """The service principal ID of the system assigned identity. This property will only be provided
     for a system assigned identity."""
    tenant_id: Optional[str] = rest_field(name="tenantId", visibility=["read"])
    """The tenant ID of the system assigned identity. This property will only be provided for a system
     assigned identity."""
    type: Union[str, "_models.ManagedServiceIdentityType"] = rest_field(
        visibility=["read", "create", "update", "delete", "query"]
    )
    """The type of managed identity assigned to this resource. Required. Known values are: \"None\",
     \"SystemAssigned\", \"UserAssigned\", and \"SystemAssigned,UserAssigned\"."""
    user_assigned_identities: Optional[dict[str, "_models.UserAssignedIdentity"]] = rest_field(
        name="userAssignedIdentities", visibility=["read", "create", "update", "delete", "query"]
    )
    """The identities assigned to this resource by the user."""

    @overload
    def __init__(
        self,
        *,
        type: Union[str, "_models.ManagedServiceIdentityType"],
        user_assigned_identities: Optional[dict[str, "_models.UserAssignedIdentity"]] = None,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class MarketPlaceOfferDetails(_Model):
    """Marketplace offer details of Agri solution.

    :ivar saas_offer_id: Saas offer Id. Required.
    :vartype saas_offer_id: str
    :ivar publisher_id: Publisher Id. Required.
    :vartype publisher_id: str
    """

    saas_offer_id: str = rest_field(name="saasOfferId", visibility=["read", "create", "update", "delete", "query"])
    """Saas offer Id. Required."""
    publisher_id: str = rest_field(name="publisherId", visibility=["read", "create", "update", "delete", "query"])
    """Publisher Id. Required."""

    @overload
    def __init__(
        self,
        *,
        saas_offer_id: str,
        publisher_id: str,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class MoboBrokerResource(_Model):
    """MoboBroker resource.

    :ivar id: The fully qualified resource ID of the MoboBroker resource. Example:
     ``/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}``.
     Required.
    :vartype id: str
    """

    id: str = rest_field(visibility=["read"])
    """The fully qualified resource ID of the MoboBroker resource. Example:
     ``/subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}``.
     Required."""


class Operation(_Model):
    """REST API Operation.

    :ivar name: The name of the operation, as per Resource-Based Access Control (RBAC). Examples:
     "Microsoft.Compute/virtualMachines/write", "Microsoft.Compute/virtualMachines/capture/action".
    :vartype name: str
    :ivar is_data_action: Whether the operation applies to data-plane. This is "true" for
     data-plane operations and "false" for Azure Resource Manager/control-plane operations.
    :vartype is_data_action: bool
    :ivar display: Localized display information for this particular operation.
    :vartype display: ~azure.mgmt.agricultureplatform.models.OperationDisplay
    :ivar origin: The intended executor of the operation; as in Resource Based Access Control
     (RBAC) and audit logs UX. Default value is "user,system". Known values are: "user", "system",
     and "user,system".
    :vartype origin: str or ~azure.mgmt.agricultureplatform.models.Origin
    :ivar action_type: Extensible enum. Indicates the action type. "Internal" refers to actions
     that are for internal only APIs. "Internal"
    :vartype action_type: str or ~azure.mgmt.agricultureplatform.models.ActionType
    """

    name: Optional[str] = rest_field(visibility=["read"])
    """The name of the operation, as per Resource-Based Access Control (RBAC). Examples:
     \"Microsoft.Compute/virtualMachines/write\",
     \"Microsoft.Compute/virtualMachines/capture/action\"."""
    is_data_action: Optional[bool] = rest_field(name="isDataAction", visibility=["read"])
    """Whether the operation applies to data-plane. This is \"true\" for data-plane operations and
     \"false\" for Azure Resource Manager/control-plane operations."""
    display: Optional["_models.OperationDisplay"] = rest_field(
        visibility=["read", "create", "update", "delete", "query"]
    )
    """Localized display information for this particular operation."""
    origin: Optional[Union[str, "_models.Origin"]] = rest_field(visibility=["read"])
    """The intended executor of the operation; as in Resource Based Access Control (RBAC) and audit
     logs UX. Default value is \"user,system\". Known values are: \"user\", \"system\", and
     \"user,system\"."""
    action_type: Optional[Union[str, "_models.ActionType"]] = rest_field(name="actionType", visibility=["read"])
    """Extensible enum. Indicates the action type. \"Internal\" refers to actions that are for
     internal only APIs. \"Internal\""""

    @overload
    def __init__(
        self,
        *,
        display: Optional["_models.OperationDisplay"] = None,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class OperationDisplay(_Model):
    """Localized display information for an operation.

    :ivar provider: The localized friendly form of the resource provider name, e.g. "Microsoft
     Monitoring Insights" or "Microsoft Compute".
    :vartype provider: str
    :ivar resource: The localized friendly name of the resource type related to this operation.
     E.g. "Virtual Machines" or "Job Schedule Collections".
    :vartype resource: str
    :ivar operation: The concise, localized friendly name for the operation; suitable for
     dropdowns. E.g. "Create or Update Virtual Machine", "Restart Virtual Machine".
    :vartype operation: str
    :ivar description: The short, localized friendly description of the operation; suitable for
     tool tips and detailed views.
    :vartype description: str
    """

    provider: Optional[str] = rest_field(visibility=["read"])
    """The localized friendly form of the resource provider name, e.g. \"Microsoft Monitoring
     Insights\" or \"Microsoft Compute\"."""
    resource: Optional[str] = rest_field(visibility=["read"])
    """The localized friendly name of the resource type related to this operation. E.g. \"Virtual
     Machines\" or \"Job Schedule Collections\"."""
    operation: Optional[str] = rest_field(visibility=["read"])
    """The concise, localized friendly name for the operation; suitable for dropdowns. E.g. \"Create
     or Update Virtual Machine\", \"Restart Virtual Machine\"."""
    description: Optional[str] = rest_field(visibility=["read"])
    """The short, localized friendly description of the operation; suitable for tool tips and detailed
     views."""


class Sku(_Model):
    """The resource model definition representing SKU.

    :ivar name: The name of the SKU. Ex - P3. It is typically a letter+number code. Required.
    :vartype name: str
    :ivar tier: This field is required to be implemented by the Resource Provider if the service
     has more than one tier, but is not required on a PUT. Known values are: "Free", "Basic",
     "Standard", and "Premium".
    :vartype tier: str or ~azure.mgmt.agricultureplatform.models.SkuTier
    :ivar size: The SKU size. When the name field is the combination of tier and some other value,
     this would be the standalone code.
    :vartype size: str
    :ivar family: If the service has different generations of hardware, for the same SKU, then that
     can be captured here.
    :vartype family: str
    :ivar capacity: If the SKU supports scale out/in then the capacity integer should be included.
     If scale out/in is not possible for the resource this may be omitted.
    :vartype capacity: int
    """

    name: str = rest_field(visibility=["read", "create", "update", "delete", "query"])
    """The name of the SKU. Ex - P3. It is typically a letter+number code. Required."""
    tier: Optional[Union[str, "_models.SkuTier"]] = rest_field(
        visibility=["read", "create", "update", "delete", "query"]
    )
    """This field is required to be implemented by the Resource Provider if the service has more than
     one tier, but is not required on a PUT. Known values are: \"Free\", \"Basic\", \"Standard\",
     and \"Premium\"."""
    size: Optional[str] = rest_field(visibility=["read", "create", "update", "delete", "query"])
    """The SKU size. When the name field is the combination of tier and some other value, this would
     be the standalone code."""
    family: Optional[str] = rest_field(visibility=["read", "create", "update", "delete", "query"])
    """If the service has different generations of hardware, for the same SKU, then that can be
     captured here."""
    capacity: Optional[int] = rest_field(visibility=["read", "create", "update", "delete", "query"])
    """If the SKU supports scale out/in then the capacity integer should be included. If scale out/in
     is not possible for the resource this may be omitted."""

    @overload
    def __init__(
        self,
        *,
        name: str,
        tier: Optional[Union[str, "_models.SkuTier"]] = None,
        size: Optional[str] = None,
        family: Optional[str] = None,
        capacity: Optional[int] = None,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class Solution(_Model):
    """Installed data manager for Agriculture solution detail.

    :ivar application_name: Application name of the solution.
    :vartype application_name: str
    :ivar partner_id: Partner Id.
    :vartype partner_id: str
    :ivar market_place_publisher_id: Marketplace publisher Id.
    :vartype market_place_publisher_id: str
    :ivar saas_subscription_id: Saas subscription Id.
    :vartype saas_subscription_id: str
    :ivar saas_subscription_name: Saas subscription name.
    :vartype saas_subscription_name: str
    :ivar plan_id: Plan Id.
    :vartype plan_id: str
    """

    application_name: Optional[str] = rest_field(name="applicationName", visibility=["read", "create", "update"])
    """Application name of the solution."""
    partner_id: Optional[str] = rest_field(name="partnerId", visibility=["read", "create", "update"])
    """Partner Id."""
    market_place_publisher_id: Optional[str] = rest_field(
        name="marketPlacePublisherId", visibility=["read", "create", "update"]
    )
    """Marketplace publisher Id."""
    saas_subscription_id: Optional[str] = rest_field(name="saasSubscriptionId", visibility=["read", "create", "update"])
    """Saas subscription Id."""
    saas_subscription_name: Optional[str] = rest_field(
        name="saasSubscriptionName", visibility=["read", "create", "update"]
    )
    """Saas subscription name."""
    plan_id: Optional[str] = rest_field(name="planId", visibility=["read", "create", "update"])
    """Plan Id."""

    @overload
    def __init__(
        self,
        *,
        application_name: Optional[str] = None,
        partner_id: Optional[str] = None,
        market_place_publisher_id: Optional[str] = None,
        saas_subscription_id: Optional[str] = None,
        saas_subscription_name: Optional[str] = None,
        plan_id: Optional[str] = None,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class SystemData(_Model):
    """Metadata pertaining to creation and last modification of the resource.

    :ivar created_by: The identity that created the resource.
    :vartype created_by: str
    :ivar created_by_type: The type of identity that created the resource. Known values are:
     "User", "Application", "ManagedIdentity", and "Key".
    :vartype created_by_type: str or ~azure.mgmt.agricultureplatform.models.CreatedByType
    :ivar created_at: The timestamp of resource creation (UTC).
    :vartype created_at: ~datetime.datetime
    :ivar last_modified_by: The identity that last modified the resource.
    :vartype last_modified_by: str
    :ivar last_modified_by_type: The type of identity that last modified the resource. Known values
     are: "User", "Application", "ManagedIdentity", and "Key".
    :vartype last_modified_by_type: str or ~azure.mgmt.agricultureplatform.models.CreatedByType
    :ivar last_modified_at: The timestamp of resource last modification (UTC).
    :vartype last_modified_at: ~datetime.datetime
    """

    created_by: Optional[str] = rest_field(name="createdBy", visibility=["read", "create", "update", "delete", "query"])
    """The identity that created the resource."""
    created_by_type: Optional[Union[str, "_models.CreatedByType"]] = rest_field(
        name="createdByType", visibility=["read", "create", "update", "delete", "query"]
    )
    """The type of identity that created the resource. Known values are: \"User\", \"Application\",
     \"ManagedIdentity\", and \"Key\"."""
    created_at: Optional[datetime.datetime] = rest_field(
        name="createdAt", visibility=["read", "create", "update", "delete", "query"], format="rfc3339"
    )
    """The timestamp of resource creation (UTC)."""
    last_modified_by: Optional[str] = rest_field(
        name="lastModifiedBy", visibility=["read", "create", "update", "delete", "query"]
    )
    """The identity that last modified the resource."""
    last_modified_by_type: Optional[Union[str, "_models.CreatedByType"]] = rest_field(
        name="lastModifiedByType", visibility=["read", "create", "update", "delete", "query"]
    )
    """The type of identity that last modified the resource. Known values are: \"User\",
     \"Application\", \"ManagedIdentity\", and \"Key\"."""
    last_modified_at: Optional[datetime.datetime] = rest_field(
        name="lastModifiedAt", visibility=["read", "create", "update", "delete", "query"], format="rfc3339"
    )
    """The timestamp of resource last modification (UTC)."""

    @overload
    def __init__(
        self,
        *,
        created_by: Optional[str] = None,
        created_by_type: Optional[Union[str, "_models.CreatedByType"]] = None,
        created_at: Optional[datetime.datetime] = None,
        last_modified_by: Optional[str] = None,
        last_modified_by_type: Optional[Union[str, "_models.CreatedByType"]] = None,
        last_modified_at: Optional[datetime.datetime] = None,
    ) -> None: ...

    @overload
    def __init__(self, mapping: Mapping[str, Any]) -> None:
        """
        :param mapping: raw JSON to initialize the model.
        :type mapping: Mapping[str, Any]
        """

    def __init__(self, *args: Any, **kwargs: Any) -> None:
        super().__init__(*args, **kwargs)


class UserAssignedIdentity(_Model):
    """User assigned identity properties.

    :ivar principal_id: The principal ID of the assigned identity.
    :vartype principal_id: str
    :ivar client_id: The client ID of the assigned identity.
    :vartype client_id: str
    """

    principal_id: Optional[str] = rest_field(name="principalId", visibility=["read"])
    """The principal ID of the assigned identity."""
    client_id: Optional[str] = rest_field(name="clientId", visibility=["read"])
    """The client ID of the assigned identity."""



import os

from unittest.mock import patch

from tempfile import TemporaryDirectory

from ci_tools.functions import find_whl, find_sdist


integration_folder = os.path.join(os.path.dirname(__file__), "integration")
tags_folder = os.path.join(integration_folder, "scenarios", "sample_interpreter_tags")


def create_basic_temp_dir(tmp_directory_create) -> str:
    tmp_dir = tmp_directory_create(
        [
            os.path.join("azure-common", "azure_common-1.1.29-py3-none-any.whl"),
            os.path.join("azure-core", "azure_core-1.26.5-py3-none-any.whl"),
            os.path.join("azure-core-experimental", "azure_core_experimental-1.0.0b3-py3-none-any.whl"),
            os.path.join("azure-tracing-opencensus", "azure_core_tracing_opencensus-1.0.0b9-py3-none-any.whl"),
            os.path.join(
                "azure-core-tracing-opentelemetry", "azure_core_tracing_opentelemetry-1.0.0b10-py3-none-any.whl"
            ),
            os.path.join("azure-mgmt-core", "azure_mgmt_core-1.4.0-py3-none-any.whl"),
            os.path.join(
                "azure-servicemanagement-legacy", "azure_servicemanagement_legacy-0.20.7-py2.py3-none-any.whl"
            ),
        ]
    )
    return tmp_dir


@patch("ci_tools.functions.get_interpreter_compatible_tags")
def test_find_discovers_standard_whls(test_patch, tmp_directory_create):
    tmp_dir = create_basic_temp_dir(tmp_directory_create)
    test_patch.return_value = ["py3-none-any"]

    # basic positive cases
    found_core = find_whl(tmp_dir, "azure-core", "1.26.5")
    found_legacy = find_whl(tmp_dir, "azure-servicemanagement-legacy", "0.20.7")
    assert found_core is not None
    assert found_legacy is not None

    # basic negative cases
    not_found_core = find_whl(tmp_dir, "azure-core", "1.26.4")
    assert not_found_core is None


@patch("ci_tools.functions.get_interpreter_compatible_tags")
def test_find_whl_fails_on_incompatible_interpreter(test_patch, tmp_directory_create):
    tmp_dir = create_basic_temp_dir(tmp_directory_create)
    test_patch.return_value = []

    found = find_whl(tmp_dir, "azure-core", "1.26.5")
    assert found is None


@patch("ci_tools.functions.get_interpreter_compatible_tags")
def test_find_whl_discovers_specific_wheels(test_patch, tmp_directory_create):
    tmp_dir = tmp_directory_create(
        [
            "azure_storage_extensions-1.0.0b1-cp310-cp310-macosx_10_9_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp310-cp310-manylinux_2_5_i686.manylinux1_i686.manylinux_2_17_i686.manylinux2014_i686.whl",
            "azure_storage_extensions-1.0.0b1-cp310-cp310-manylinux_2_5_x86_64.manylinux1_x86_64.manylinux_2_17_x86_64.manylinux2014_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp310-cp310-win_amd64.whl",
            "azure_storage_extensions-1.0.0b1-cp310-cp310-win32.whl",
            "azure_storage_extensions-1.0.0b1-cp311-cp311-macosx_10_9_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp311-cp311-manylinux_2_5_i686.manylinux1_i686.manylinux_2_17_i686.manylinux2014_i686.whl",
            "azure_storage_extensions-1.0.0b1-cp311-cp311-manylinux_2_5_x86_64.manylinux1_x86_64.manylinux_2_17_x86_64.manylinux2014_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp311-cp311-win_amd64.whl",
            "azure_storage_extensions-1.0.0b1-cp311-cp311-win32.whl",
            "azure_storage_extensions-1.0.0b1-cp312-cp312-macosx_10_9_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp312-cp312-manylinux_2_5_i686.manylinux1_i686.manylinux_2_17_i686.manylinux2014_i686.whl",
            "azure_storage_extensions-1.0.0b1-cp312-cp312-manylinux_2_5_x86_64.manylinux1_x86_64.manylinux_2_17_x86_64.manylinux2014_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp312-cp312-win_amd64.whl",
            "azure_storage_extensions-1.0.0b1-cp312-cp312-win32.whl",
            "azure_storage_extensions-1.0.0b1-cp37-cp37m-macosx_10_9_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp37-cp37m-manylinux_2_5_i686.manylinux1_i686.manylinux_2_17_i686.manylinux2014_i686.whl",
            "azure_storage_extensions-1.0.0b1-cp37-cp37m-manylinux_2_5_x86_64.manylinux1_x86_64.manylinux_2_17_x86_64.manylinux2014_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp37-cp37m-win_amd64.whl",
            "azure_storage_extensions-1.0.0b1-cp37-cp37m-win32.whl",
            "azure_storage_extensions-1.0.0b1-cp38-cp38-macosx_10_9_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp38-cp38-manylinux_2_5_i686.manylinux1_i686.manylinux_2_17_i686.manylinux2014_i686.whl",
            "azure_storage_extensions-1.0.0b1-cp38-cp38-manylinux_2_5_x86_64.manylinux1_x86_64.manylinux_2_17_x86_64.manylinux2014_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp38-cp38-win_amd64.whl",
            "azure_storage_extensions-1.0.0b1-cp38-cp38-win32.whl",
            "azure_storage_extensions-1.0.0b1-cp39-cp39-linux_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp39-cp39-macosx_10_9_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp39-cp39-macosx_11_0_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp39-cp39-manylinux_2_5_i686.manylinux1_i686.manylinux_2_17_i686.manylinux2014_i686.whl",
            "azure_storage_extensions-1.0.0b1-cp39-cp39-manylinux_2_5_x86_64.manylinux1_x86_64.manylinux_2_17_x86_64.manylinux2014_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp39-cp39-win_amd64.whl",
            "azure_storage_extensions-1.0.0b1-cp39-cp39-win32.whl",
            "azure-storage-extensions-1.0.0b1.tar.gz",
        ]
    )

    with open(os.path.join(tags_folder, "from_WSL_310.txt"), "r", encoding="utf-8") as f:
        compatible_tags = [line.strip() for line in f.readlines()]

    test_patch.return_value = compatible_tags
    found = find_whl(tmp_dir, "azure-storage-extensions", "1.0.0b1")
    assert isinstance(found, str)


@patch("ci_tools.functions.get_interpreter_compatible_tags")
def test_find_sdist_discovers_specific_sdist(test_patch, tmp_directory_create):
    tmp_dir = tmp_directory_create(
        [
            "azure_storage_extensions-1.0.0b1-cp310-cp310-macosx_10_9_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp310-cp310-manylinux_2_5_i686.manylinux1_i686.manylinux_2_17_i686.manylinux2014_i686.whl",
            "azure_storage_extensions-1.0.0b1-cp310-cp310-manylinux_2_5_x86_64.manylinux1_x86_64.manylinux_2_17_x86_64.manylinux2014_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp310-cp310-win_amd64.whl",
            "azure_storage_extensions-1.0.0b1-cp310-cp310-win32.whl",
            "azure_storage_extensions-1.0.0b1-cp311-cp311-macosx_10_9_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp311-cp311-manylinux_2_5_i686.manylinux1_i686.manylinux_2_17_i686.manylinux2014_i686.whl",
            "azure_storage_extensions-1.0.0b1-cp311-cp311-manylinux_2_5_x86_64.manylinux1_x86_64.manylinux_2_17_x86_64.manylinux2014_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp311-cp311-win_amd64.whl",
            "azure_storage_extensions-1.0.0b1-cp311-cp311-win32.whl",
            "azure_storage_extensions-1.0.0b1-cp312-cp312-macosx_10_9_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp312-cp312-manylinux_2_5_i686.manylinux1_i686.manylinux_2_17_i686.manylinux2014_i686.whl",
            "azure_storage_extensions-1.0.0b1-cp312-cp312-manylinux_2_5_x86_64.manylinux1_x86_64.manylinux_2_17_x86_64.manylinux2014_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp312-cp312-win_amd64.whl",
            "azure_storage_extensions-1.0.0b1-cp312-cp312-win32.whl",
            "azure_storage_extensions-1.0.0b1-cp37-cp37m-macosx_10_9_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp37-cp37m-manylinux_2_5_i686.manylinux1_i686.manylinux_2_17_i686.manylinux2014_i686.whl",
            "azure_storage_extensions-1.0.0b1-cp37-cp37m-manylinux_2_5_x86_64.manylinux1_x86_64.manylinux_2_17_x86_64.manylinux2014_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp37-cp37m-win_amd64.whl",
            "azure_storage_extensions-1.0.0b1-cp37-cp37m-win32.whl",
            "azure_storage_extensions-1.0.0b1-cp38-cp38-macosx_10_9_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp38-cp38-manylinux_2_5_i686.manylinux1_i686.manylinux_2_17_i686.manylinux2014_i686.whl",
            "azure_storage_extensions-1.0.0b1-cp38-cp38-manylinux_2_5_x86_64.manylinux1_x86_64.manylinux_2_17_x86_64.manylinux2014_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp38-cp38-win_amd64.whl",
            "azure_storage_extensions-1.0.0b1-cp38-cp38-win32.whl",
            "azure_storage_extensions-1.0.0b1-cp39-cp39-linux_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp39-cp39-macosx_10_9_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp39-cp39-macosx_11_0_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp39-cp39-manylinux_2_5_i686.manylinux1_i686.manylinux_2_17_i686.manylinux2014_i686.whl",
            "azure_storage_extensions-1.0.0b1-cp39-cp39-manylinux_2_5_x86_64.manylinux1_x86_64.manylinux_2_17_x86_64.manylinux2014_x86_64.whl",
            "azure_storage_extensions-1.0.0b1-cp39-cp39-win_amd64.whl",
            "azure_storage_extensions-1.0.0b1-cp39-cp39-win32.whl",
            "azure-storage-extensions-1.0.0b1.tar.gz",
        ]
    )

    with open(os.path.join(tags_folder, "from_WSL_310.txt"), "r", encoding="utf-8") as f:
        compatible_tags = [line.strip() for line in f.readlines()]

    test_patch.return_value = compatible_tags
    found = find_sdist(tmp_dir, "azure-storage-extensions", "1.0.0b1")
    assert isinstance(found, str)



# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# --------------------------------------------------------------------------------------------

import requests

from devtools_testutils.perfstress_tests import PerfStressTest


class RequestsGetTest(PerfStressTest):
    async def global_setup(self):
        type(self).session = requests.Session()

    def run_sync(self):
        type(self).session.get(self.args.url).text

    @staticmethod
    def add_arguments(parser):
        parser.add_argument("-u", "--url", required=True)
